@@ -259,6 +259,14 @@ main (int argc, char **argv)
 		cache_dir = g_strdup ("./cache");
 	setlocale (LC_ALL, "");
 
+	/* obsolete */
+	if (api_version < 0.6) {
+		/* TRANSLATORS: error message */
+		g_warning ("%s", _("API version no longer supported"));
+		retval = EXIT_FAILURE;
+		goto out;
+	}
+
 	/* this really ought to be set */
 	if (basename == NULL) {
 		g_print ("WARNING: Metadata basename not set, using 'appstream'\n");
@@ -293,6 +301,26 @@ main (int argc, char **argv)
 				flags |= ASB_CONTEXT_FLAG_IGNORE_MISSING_PARENTS;
 				continue;
 			}
+			if (g_strcmp0 (veto_ignore[i], "dead-upstream") == 0) {
+				flags |= ASB_CONTEXT_FLAG_IGNORE_DEAD_UPSTREAM;
+				continue;
+			}
+			if (g_strcmp0 (veto_ignore[i], "obsolete-deps") == 0) {
+				flags |= ASB_CONTEXT_FLAG_IGNORE_OBSOLETE_DEPS;
+				continue;
+			}
+			if (g_strcmp0 (veto_ignore[i], "legacy-icons") == 0) {
+				flags |= ASB_CONTEXT_FLAG_IGNORE_LEGACY_ICONS;
+				continue;
+			}
+			if (g_strcmp0 (veto_ignore[i], "ignore-settings") == 0) {
+				flags |= ASB_CONTEXT_FLAG_IGNORE_SETTINGS;
+				continue;
+			}
+			if (g_strcmp0 (veto_ignore[i], "use-fallbacks") == 0) {
+				flags |= ASB_CONTEXT_FLAG_USE_FALLBACKS;
+				continue;
+			}
 			g_warning ("Unknown flag name: %s, "
 				   "expected 'missing-info' or 'missing-parents'",
 				   veto_ignore[i]);
