@@ -248,96 +248,6 @@ asb_app_save_resources (AsbApp *app, AsbAppSaveFlags save_flags, GError **error)
 	return TRUE;
 }
 
-/**
- * asb_app_add_screenshot_source:
- * @app: A #AsbApp
- * @filename: filename to the source image
- * @error: A #GError or %NULL
- *
- * Adds a screenshot from a previously saved image.
- *
- * Returns: %TRUE for success, %FALSE otherwise
- *
- * Since: 0.1.0
- **/
-gboolean
-asb_app_add_screenshot_source (AsbApp *app, const gchar *filename, GError **error)
-{
-	AsImageAlphaFlags alpha_flags;
-	gboolean is_default;
-	_cleanup_free_ gchar *basename = NULL;
-	_cleanup_free_ gchar *filename_no_path = NULL;
-	_cleanup_free_ gchar *url_src = NULL;
-	_cleanup_object_unref_ AsImage *im_src = NULL;
-	_cleanup_object_unref_ AsScreenshot *ss = NULL;
-
-	im_src = as_image_new ();
-	if (!as_image_load_filename (im_src, filename, error))
-		return FALSE;
-
-	/* is the aspect ratio of the source perfectly 16:9 */
-	if ((as_image_get_width (im_src) / 16) * 9 !=
-	     as_image_get_height (im_src)) {
-		filename_no_path = g_path_get_basename (filename);
-		asb_package_log (asb_app_get_package (app),
-				 ASB_PACKAGE_LOG_LEVEL_WARNING,
-				 "%s is not in 16:9 aspect ratio",
-				 filename_no_path);
-	}
-
-	/* check screenshot is reasonable in size */
-	if (as_image_get_width (im_src) * 2 < AS_IMAGE_NORMAL_WIDTH ||
-	    as_image_get_height (im_src) * 2 < AS_IMAGE_NORMAL_HEIGHT) {
-		filename_no_path = g_path_get_basename (filename);
-		g_set_error (error,
-			     AS_APP_ERROR,
-			     AS_APP_ERROR_FAILED,
-			     "%s is too small to be used: %ix%i",
-			     filename_no_path,
-			     as_image_get_width (im_src),
-			     as_image_get_height (im_src));
-		return FALSE;
-	}
-
-	/* check the image is not padded */
-	alpha_flags = as_image_get_alpha_flags (im_src);
-	if ((alpha_flags & AS_IMAGE_ALPHA_FLAG_TOP) > 0||
-	    (alpha_flags & AS_IMAGE_ALPHA_FLAG_BOTTOM) > 0) {
-		filename_no_path = g_path_get_basename (filename);
-		asb_package_log (asb_app_get_package (app),
-				 ASB_PACKAGE_LOG_LEVEL_WARNING,
-				 "%s has vertical alpha padding",
-				 filename_no_path);
-	}
-	if ((alpha_flags & AS_IMAGE_ALPHA_FLAG_LEFT) > 0||
-	    (alpha_flags & AS_IMAGE_ALPHA_FLAG_RIGHT) > 0) {
-		filename_no_path = g_path_get_basename (filename);
-		asb_package_log (asb_app_get_package (app),
-				 ASB_PACKAGE_LOG_LEVEL_WARNING,
-				 "%s has horizontal alpha padding",
-				 filename_no_path);
-	}
-
-	ss = as_screenshot_new ();
-	is_default = as_app_get_screenshots(AS_APP(app))->len == 0;
-	as_screenshot_set_kind (ss, is_default ? AS_SCREENSHOT_KIND_DEFAULT :
-						 AS_SCREENSHOT_KIND_NORMAL);
-
-	/* include the app-id in the basename */
-	basename = g_strdup_printf ("%s-%s.png",
-				    as_app_get_id_filename (AS_APP (app)),
-				    as_image_get_md5 (im_src));
-	as_image_set_basename (im_src, basename);
-
-	/* fonts only have full sized screenshots */
-	url_src = g_build_filename ("file://", basename, NULL);
-	as_image_set_url (im_src, url_src, -1);
-	as_image_set_kind (im_src, AS_IMAGE_KIND_SOURCE);
-	as_screenshot_add_image (ss, im_src);
-	as_app_add_screenshot (AS_APP (app), ss);
-	return TRUE;
-}
-
 /**
  * asb_app_new:
  * @pkg: A #AsbPackage
@@ -362,13 +272,13 @@ asb_app_new (AsbPackage *pkg, const gchar *id)
 		switch (asb_package_get_kind (pkg)) {
 		case ASB_PACKAGE_KIND_DEFAULT:
 			as_app_add_pkgname (AS_APP (app),
-					    asb_package_get_name (pkg), -1);
+					    asb_package_get_name (pkg));
 			break;
 		case ASB_PACKAGE_KIND_BUNDLE:
 		{
 			_cleanup_object_unref_ AsBundle *bundle = NULL;
 			bundle = as_bundle_new ();
-			as_bundle_set_id (bundle, asb_package_get_source (pkg), -1);
+			as_bundle_set_id (bundle, asb_package_get_source (pkg));
 			as_bundle_set_kind (bundle, AS_BUNDLE_KIND_XDG_APP);
 			as_app_add_bundle (AS_APP (app), bundle);
 		};
@@ -377,6 +287,6 @@ asb_app_new (AsbPackage *pkg, const gchar *id)
 		}
 	}
 	if (id != NULL)
-		as_app_set_id (AS_APP (app), id, -1);
+		as_app_set_id (AS_APP (app), id);
 	return ASB_APP (app);
 }
