@@ -105,6 +105,8 @@ asb_package_rpm_set_license (AsbPackage *pkg, const gchar *license)
 		{ "CDDL",			"CDDL-1.0" },
 		{ "CeCILL-C",			"CECILL-C" },
 		{ "CeCILL",			"CECILL-2.0" },
+		{ "CPAL",			"CPAL-1.0" },
+		{ "CPL",			"CPL-1.0" },
 		{ "EPL",			"EPL-1.0" },
 		{ "Free Art",			"ClArtistic" },
 		{ "GFDL",			"GFDL-1.3" },
@@ -368,7 +370,7 @@ asb_package_rpm_add_release (AsbPackage *pkg,
 			as_release_set_timestamp (release, timestamp);
 	} else {
 		release = as_release_new ();
-		as_release_set_version (release, version, -1);
+		as_release_set_version (release, version);
 		as_release_set_timestamp (release, timestamp);
 		asb_package_add_release (pkg, version, release);
 		g_object_unref (release);
