@@ -72,6 +72,8 @@ struct _AsbPackageClass
 						 GError		**error);
 	gint			 (*compare)	(AsbPackage	*pkg1,
 						 AsbPackage	*pkg2);
+	gboolean		 (*close)	(AsbPackage	*pkg,
+						 GError		**error);
 	/*< private >*/
 	void (*_asb_reserved1)	(void);
 	void (*_asb_reserved2)	(void);
@@ -80,7 +82,6 @@ struct _AsbPackageClass
 	void (*_asb_reserved5)	(void);
 	void (*_asb_reserved6)	(void);
 	void (*_asb_reserved7)	(void);
-	void (*_asb_reserved8)	(void);
 };
 
 typedef enum {
@@ -91,6 +92,13 @@ typedef enum {
 	ASB_PACKAGE_LOG_LEVEL_LAST,
 } AsbPackageLogLevel;
 
+typedef enum {
+	ASB_PACKAGE_KIND_DEFAULT,
+	ASB_PACKAGE_KIND_BUNDLE,
+	ASB_PACKAGE_KIND_FIRMWARE,
+	ASB_PACKAGE_KIND_LAST
+} AsbPackageKind;
+
 GType		 asb_package_get_type		(void);
 
 void		 asb_package_log_start		(AsbPackage	*pkg);
@@ -104,17 +112,23 @@ gboolean	 asb_package_log_flush		(AsbPackage	*pkg,
 gboolean	 asb_package_open		(AsbPackage	*pkg,
 						 const gchar	*filename,
 						 GError		**error);
+gboolean	 asb_package_close		(AsbPackage	*pkg,
+						 GError		**error);
 gboolean	 asb_package_ensure		(AsbPackage	*pkg,
 						 AsbPackageEnsureFlags flags,
 						 GError		**error);
+void		 asb_package_clear		(AsbPackage	*pkg,
+						 AsbPackageEnsureFlags flags);
 gboolean	 asb_package_explode		(AsbPackage	*pkg,
 						 const gchar	*dir,
 						 GPtrArray	*glob,
 						 GError		**error);
+AsbPackageKind	 asb_package_get_kind		(AsbPackage	*pkg);
 const gchar	*asb_package_get_filename	(AsbPackage	*pkg);
 const gchar	*asb_package_get_basename	(AsbPackage	*pkg);
 const gchar	*asb_package_get_arch		(AsbPackage	*pkg);
 const gchar	*asb_package_get_name		(AsbPackage	*pkg);
+const gchar	*asb_package_get_version	(AsbPackage	*pkg);
 const gchar	*asb_package_get_nevr		(AsbPackage	*pkg);
 const gchar	*asb_package_get_nevra		(AsbPackage	*pkg);
 const gchar	*asb_package_get_evr		(AsbPackage	*pkg);
@@ -123,8 +137,12 @@ const gchar	*asb_package_get_vcs		(AsbPackage	*pkg);
 const gchar	*asb_package_get_license	(AsbPackage	*pkg);
 const gchar	*asb_package_get_source		(AsbPackage	*pkg);
 const gchar	*asb_package_get_source_pkgname	(AsbPackage	*pkg);
+void		 asb_package_set_kind		(AsbPackage	*pkg,
+						 AsbPackageKind	 kind);
 void		 asb_package_set_name		(AsbPackage	*pkg,
 						 const gchar	*name);
+void		 asb_package_set_filename	(AsbPackage	*pkg,
+						 const gchar	*filename);
 void		 asb_package_set_version	(AsbPackage	*pkg,
 						 const gchar	*version);
 void		 asb_package_set_release	(AsbPackage	*pkg,
@@ -143,12 +161,12 @@ void		 asb_package_set_source		(AsbPackage	*pkg,
 						 const gchar	*source);
 void		 asb_package_set_source_pkgname	(AsbPackage	*pkg,
 						 const gchar	*source_pkgname);
-void		 asb_package_set_deps		(AsbPackage	*pkg,
-						 gchar		**deps);
+void		 asb_package_add_dep		(AsbPackage	*pkg,
+						 const gchar	*dep);
 void		 asb_package_set_filelist	(AsbPackage	*pkg,
 						 gchar		**filelist);
 gchar		**asb_package_get_filelist	(AsbPackage	*pkg);
-gchar		**asb_package_get_deps		(AsbPackage	*pkg);
+GPtrArray	*asb_package_get_deps		(AsbPackage	*pkg);
 GPtrArray	*asb_package_get_releases	(AsbPackage	*pkg);
 void		 asb_package_set_config		(AsbPackage	*pkg,
 						 const gchar	*key,
