@@ -80,8 +80,6 @@ typedef gboolean	 (*AsbPluginProcessAppFunc)	(AsbPlugin	*plugin,
 const gchar	*asb_plugin_get_name			(void);
 void		 asb_plugin_initialize			(AsbPlugin	*plugin);
 void		 asb_plugin_destroy			(AsbPlugin	*plugin);
-void		 asb_plugin_set_enabled			(AsbPlugin	*plugin,
-							 gboolean	 enabled);
 GList		*asb_plugin_process			(AsbPlugin	*plugin,
 							 AsbPackage	*pkg,
 							 const gchar	*tmpdir,
