@@ -260,6 +260,7 @@ asb_test_plugin_loader_func (void)
 	/* set up loader */
 	ctx = asb_context_new ();
 	loader = asb_context_get_plugin_loader (ctx);
+	asb_plugin_loader_set_dir (loader, TESTPLUGINDIR);
 	ret = asb_plugin_loader_setup (loader, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
@@ -299,6 +300,7 @@ static void
 asb_test_context_test_func (AsbTestContextMode mode)
 {
 	AsApp *app;
+	AsbPluginLoader *loader;
 	GError *error = NULL;
 	const gchar *expected_xml;
 	gboolean ret;
@@ -356,6 +358,8 @@ asb_test_context_test_func (AsbTestContextMode mode)
 	}
 	g_assert (asb_context_get_flag (ctx, ASB_CONTEXT_FLAG_ADD_CACHE_ID));
 	g_assert_cmpstr (asb_context_get_temp_dir (ctx), ==, "/tmp/asbuilder/temp");
+	loader = asb_context_get_plugin_loader (ctx);
+	asb_plugin_loader_set_dir (loader, TESTPLUGINDIR);
 	ret = asb_context_setup (ctx, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
@@ -412,40 +416,19 @@ asb_test_context_test_func (AsbTestContextMode mode)
 	xml = as_store_to_xml (store, AS_NODE_TO_XML_FLAG_FORMAT_MULTILINE);
 	expected_xml =
 		"<components version=\"0.9\" builder_id=\"appstream-glib:4\" origin=\"asb-self-test\">\n"
-		"<component type=\"firmware\">\n"
-		"<id>84f40464-9272-4ef7-9399-cd95f12da696</id>\n"
-		"<name>ColorHug Firmware</name>\n"
-		"<summary>Firmware for the ColorHug Colorimeter</summary>\n"
-		"<developer_name>Hughski</developer_name>\n"
-		"<description><p>Updating the firmware on your ColorHug device "
-		"improves performance and adds new features.</p></description>\n"
-		"<icon type=\"stock\">application-x-executable</icon>\n"
-		"<kudos>\n"
-		"<kudo>HiDpiIcon</kudo>\n"
-		"</kudos>\n"
-		"<url type=\"homepage\">http://www.hughski.com/</url>\n"
-		"<releases>\n"
-		"<release version=\"2.0.2\" timestamp=\"1424116753\">\n"
-		"<location>http://www.hughski.com/downloads/colorhug2/firmware/colorhug-2.0.2.cab</location>\n"
-		"<checksum type=\"sha1\">ab2d0294e0d23c1718af79c6a17216c8322ae6da</checksum>\n"
-		"<description><p>This unstable release adds the following features:</p>"
-		"<ul><li>Add TakeReadingArray to enable panel latency measurements</li>"
-		"<li>Speed up the auto-scaled measurements considerably, using 256ms "
-		"as the smallest sample duration</li></ul></description>\n"
-		"</release>\n"
-		"</releases>\n"
-		"<metadata>\n"
-		"<value key=\"X-CacheID\">colorhug-als-2.0.2.cab</value>\n"
-		"</metadata>\n"
-		"</component>\n"
 		"<component type=\"font\">\n"
 		"<id>Liberation</id>\n"
 		"<pkgname>font</pkgname>\n"
 		"<pkgname>font-serif</pkgname>\n"
+		"<source_pkgname>font</source_pkgname>\n"
 		"<name>Liberation</name>\n"
 		"<summary>Open source versions of several commecial fonts</summary>\n"
 		"<description><p>The Liberation Fonts are intended to be replacements for Times New Roman, Arial, and Courier New.</p></description>\n"
 		"<icon height=\"64\" width=\"64\" type=\"cached\">LiberationSerif.png</icon>\n"
+		"<categories>\n"
+		"<category>Addons</category>\n"
+		"<category>Fonts</category>\n"
+		"</categories>\n"
 		"<project_license>GPL-2.0+</project_license>\n"
 		"<url type=\"homepage\">http://people.freedesktop.org/</url>\n"
 		"<screenshots>\n"
@@ -534,6 +517,33 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"<value key=\"X-CacheID\">app-1-1.fc21.x86_64.rpm</value>\n"
 		"</metadata>\n"
 		"</component>\n"
+		"<component type=\"firmware\">\n"
+		"<id>com.hughski.ColorHug2.firmware</id>\n"
+		"<name>ColorHug Firmware</name>\n"
+		"<summary>Firmware for the ColorHug Colorimeter</summary>\n"
+		"<developer_name>Hughski Limited</developer_name>\n"
+		"<description><p>Updating the firmware on your ColorHug device "
+		"improves performance and adds new features.</p></description>\n"
+		"<icon type=\"stock\">application-x-executable</icon>\n"
+		"<url type=\"homepage\">http://www.hughski.com/</url>\n"
+		"<releases>\n"
+		"<release version=\"2.0.2\" timestamp=\"1424116753\">\n"
+		"<location>http://www.hughski.com/downloads/colorhug2/firmware/colorhug-2.0.2.cab</location>\n"
+		"<checksum filename=\"colorhug-als-2.0.2.cab\" target=\"container\" type=\"sha1\">6301e24ae5fb2aa73c336fd40a5d2f1835afe088</checksum>\n"
+		"<checksum filename=\"firmware.bin\" target=\"content\" type=\"sha1\">767a8a7b8a7b350b513f57761204b4aaa657aa44</checksum>\n"
+		"<description><p>This unstable release adds the following features:</p>"
+		"<ul><li>Add TakeReadingArray to enable panel latency measurements</li>"
+		"<li>Speed up the auto-scaled measurements considerably, using 256ms "
+		"as the smallest sample duration</li></ul></description>\n"
+		"</release>\n"
+		"</releases>\n"
+		"<provides>\n"
+		"<firmware type=\"flashed\">84f40464-9272-4ef7-9399-cd95f12da696</firmware>\n"
+		"</provides>\n"
+		"<metadata>\n"
+		"<value key=\"X-CacheID\">colorhug-als-2.0.2.cab</value>\n"
+		"</metadata>\n"
+		"</component>\n"
 		"<component type=\"desktop\">\n"
 		"<id>valid1.desktop</id>\n"
 		"<pkgname>composite</pkgname>\n"
@@ -743,24 +753,28 @@ asb_test_context_test_func (AsbTestContextMode mode)
 		"<components version=\"0.9\" builder_id=\"appstream-glib:4\" origin=\"asb-self-test-ignore\">\n"
 		"<component>\n"
 		"<id>app-console.noarch</id>\n"
+		"<pkgname>app-console</pkgname>\n"
 		"<metadata>\n"
 		"<value key=\"X-CacheID\">app-console-1-1.fc21.noarch.rpm</value>\n"
 		"</metadata>\n"
 		"</component>\n"
 		"<component>\n"
 		"<id>app.i686</id>\n"
+		"<pkgname>app</pkgname>\n"
 		"<metadata>\n"
 		"<value key=\"X-CacheID\">app-1-1.fc21.i686.rpm</value>\n"
 		"</metadata>\n"
 		"</component>\n"
 		"<component>\n"
 		"<id>font-serif.noarch</id>\n"
+		"<pkgname>font-serif</pkgname>\n"
 		"<metadata>\n"
 		"<value key=\"X-CacheID\">font-serif-1-1.fc21.noarch.rpm</value>\n"
 		"</metadata>\n"
 		"</component>\n"
 		"<component>\n"
 		"<id>test.noarch</id>\n"
+		"<pkgname>test</pkgname>\n"
 		"<metadata>\n"
 		"<value key=\"X-CacheID\">test-0.1-1.fc21.noarch.rpm</value>\n"
 		"</metadata>\n"
@@ -839,6 +853,7 @@ static void
 asb_test_firmware_func (void)
 {
 	AsApp *app;
+	AsbPluginLoader *loader;
 	const gchar *expected_xml;
 	gboolean ret;
 	guint i;
@@ -864,6 +879,8 @@ asb_test_firmware_func (void)
 	asb_context_set_output_dir (ctx, "/tmp/asbuilder/output");
 	asb_context_set_temp_dir (ctx, "/tmp/asbuilder/temp");
 	asb_context_set_icons_dir (ctx, "/tmp/asbuilder/temp/icons");
+	loader = asb_context_get_plugin_loader (ctx);
+	asb_plugin_loader_set_dir (loader, TESTPLUGINDIR);
 	ret = asb_context_setup (ctx, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
@@ -898,7 +915,7 @@ asb_test_firmware_func (void)
 	g_assert_no_error (error);
 	g_assert (ret);
 	g_assert_cmpint (as_store_get_size (store), ==, 1);
-	app = as_store_get_app_by_id (store, "84f40464-9272-4ef7-9399-cd95f12da696");
+	app = as_store_get_app_by_id (store, "com.hughski.ColorHug2.firmware");
 	g_assert (app != NULL);
 
 	/* check it matches what we expect */
@@ -906,21 +923,19 @@ asb_test_firmware_func (void)
 	expected_xml =
 		"<components version=\"0.9\" origin=\"asb-self-test\">\n"
 		"<component type=\"firmware\">\n"
-		"<id>84f40464-9272-4ef7-9399-cd95f12da696</id>\n"
+		"<id>com.hughski.ColorHug2.firmware</id>\n"
 		"<name>ColorHug Firmware</name>\n"
 		"<summary>Firmware for the ColorHug Colorimeter</summary>\n"
-		"<developer_name>Hughski</developer_name>\n"
+		"<developer_name>Hughski Limited</developer_name>\n"
 		"<description><p>Updating the firmware on your ColorHug device "
 		"improves performance and adds new features.</p></description>\n"
 		"<icon type=\"stock\">application-x-executable</icon>\n"
-		"<kudos>\n"
-		"<kudo>HiDpiIcon</kudo>\n"
-		"</kudos>\n"
 		"<url type=\"homepage\">http://www.hughski.com/</url>\n"
 		"<releases>\n"
 		"<release version=\"2.0.2\" timestamp=\"1424116753\">\n"
 		"<location>http://www.hughski.com/downloads/colorhug2/firmware/colorhug-2.0.2.cab</location>\n"
-		"<checksum type=\"sha1\">ab2d0294e0d23c1718af79c6a17216c8322ae6da</checksum>\n"
+		"<checksum filename=\"colorhug-als-2.0.2.cab\" target=\"container\" type=\"sha1\">6301e24ae5fb2aa73c336fd40a5d2f1835afe088</checksum>\n"
+		"<checksum filename=\"firmware.bin\" target=\"content\" type=\"sha1\">767a8a7b8a7b350b513f57761204b4aaa657aa44</checksum>\n"
 		"<description><p>This unstable release adds the following features:</p>"
 		"<ul><li>Add TakeReadingArray to enable panel latency measurements</li>"
 		"<li>Speed up the auto-scaled measurements considerably, using 256ms "
@@ -928,17 +943,21 @@ asb_test_firmware_func (void)
 		"</release>\n"
 		"<release version=\"2.0.1\" timestamp=\"1424116753\">\n"
 		"<location>http://www.hughski.com/downloads/colorhug2/firmware/colorhug-2.0.1.cab</location>\n"
-		"<checksum type=\"sha1\">cc07f12dfea7103774decbcf48c47cc0604fbc4e</checksum>\n"
+		"<checksum filename=\"colorhug-als-2.0.1.cab\" target=\"container\" type=\"sha1\">7d4cab8775213cbd223a4a3b236618ced0af9447</checksum>\n"
+		"<checksum filename=\"firmware.bin\" target=\"content\" type=\"sha1\">767a8a7b8a7b350b513f57761204b4aaa657aa44</checksum>\n"
 		"<description><p>This unstable release adds the following features:</p>"
 		"<ul><li>Use TakeReadings() to do a quick non-adaptive measurement</li>"
 		"<li>Scale XYZ measurement with a constant factor to make the CCMX more "
 		"sane</li></ul></description>\n"
 		"</release>\n"
 		"<release version=\"2.0.0\" timestamp=\"1425168000\">\n"
-		"<location>http://www.hughski.com/downloads/colorhug2/firmware/colorhug-2.0.0.cab</location>\n"
-		"<checksum type=\"sha1\">81431b6d3c9f90c3137a8a132d4fb5e3681e6791</checksum>\n"
+		"<checksum filename=\"colorhug-als-2.0.0.cab\" target=\"container\" type=\"sha1\">d7b9ae5b36029de606c9b047c229d9c8f5e3807c</checksum>\n"
+		"<checksum filename=\"firmware.bin\" target=\"content\" type=\"sha1\">767a8a7b8a7b350b513f57761204b4aaa657aa44</checksum>\n"
 		"</release>\n"
 		"</releases>\n"
+		"<provides>\n"
+		"<firmware type=\"flashed\">84f40464-9272-4ef7-9399-cd95f12da696</firmware>\n"
+		"</provides>\n"
 		"</component>\n"
 		"</components>\n";
 	ret = asb_test_compare_lines (xml->str, expected_xml, &error);
