@@ -267,8 +267,6 @@ asb_utils_explode_file (struct archive_entry *entry, const gchar *dir)
 	tmp = archive_entry_symlink (entry);
 	if (tmp != NULL) {
 		_cleanup_free_ gchar *buf_link = NULL;
-		_cleanup_free_ gchar *path_link = NULL;
-		path_link = asb_utils_sanitise_path (tmp);
 		symlink_depth = asb_utils_count_directories_deep (path) - 1;
 		back_up = asb_utils_get_back_to_root (symlink_depth);
 		if (tmp[0] == '/')
@@ -301,25 +299,18 @@ asb_utils_explode (const gchar *filename,
 	const gchar *tmp;
 	gboolean ret = TRUE;
 	gboolean valid;
-	gsize len;
 	int r;
 	struct archive *arch = NULL;
 	struct archive *arch_preview = NULL;
 	struct archive_entry *entry;
-	_cleanup_free_ gchar *data = NULL;
 	_cleanup_hashtable_unref_ GHashTable *matches = NULL;
 
-	/* load file at once to avoid seeking */
-	ret = g_file_get_contents (filename, &data, &len, error);
-	if (!ret)
-		goto out;
-
 	/* populate a hash with all the files, symlinks and hardlinks that
 	 * actually need decompressing */
 	arch_preview = archive_read_new ();
 	archive_read_support_format_all (arch_preview);
 	archive_read_support_filter_all (arch_preview);
-	r = archive_read_open_memory (arch_preview, data, len);
+	r = archive_read_open_filename (arch_preview, filename, 1024 * 32);
 	if (r) {
 		ret = FALSE;
 		g_set_error (error,
@@ -377,7 +368,7 @@ asb_utils_explode (const gchar *filename,
 	arch = archive_read_new ();
 	archive_read_support_format_all (arch);
 	archive_read_support_filter_all (arch);
-	r = archive_read_open_memory (arch, data, len);
+	r = archive_read_open_filename (arch, filename, 1024 * 32);
 	if (r) {
 		ret = FALSE;
 		g_set_error (error,
@@ -451,7 +442,12 @@ asb_utils_write_archive (const gchar *filename,
 	struct stat st;
 
 	a = archive_write_new ();
-	archive_write_add_filter_gzip (a);
+	if (g_str_has_suffix (filename, ".gz"))
+		archive_write_add_filter_gzip (a);
+	if (g_str_has_suffix (filename, ".bz2"))
+		archive_write_add_filter_bzip2 (a);
+	if (g_str_has_suffix (filename, ".xz"))
+		archive_write_add_filter_xz (a);
 	archive_write_set_format_pax_restricted (a);
 	archive_write_open_filename (a, filename);
 	for (i = 0; i < files->len; i++) {
@@ -541,73 +537,6 @@ asb_utils_write_archive_dir (const gchar *filename,
 	return asb_utils_write_archive (filename, directory, files, error);
 }
 
-/**
- * asb_utils_add_apps_from_file:
- * @apps: (element-type AsbApp): applications
- * @filename: XML file to load
- * @error: A #GError or %NULL
- *
- * Add applications from a file.
- *
- * Returns: %TRUE for success, %FALSE otherwise
- *
- * Since: 0.1.0
- **/
-gboolean
-asb_utils_add_apps_from_file (GList **apps, const gchar *filename, GError **error)
-{
-	AsApp *app;
-	GPtrArray *array;
-	guint i;
-	_cleanup_object_unref_ AsStore *store = NULL;
-	_cleanup_object_unref_ GFile *file = NULL;
-
-	/* parse file */
-	store = as_store_new ();
-	file = g_file_new_for_path (filename);
-	if (!as_store_from_file (store, file, NULL, NULL, error))
-		return FALSE;
-
-	/* copy Asapp's into AsbApp's */
-	array = as_store_get_apps (store);
-	for (i = 0; i < array->len; i++) {
-		app = g_ptr_array_index (array, i);
-		as_app_set_source_file (app, filename);
-		asb_plugin_add_app (apps, app);
-	}
-	return TRUE;
-}
-
-/**
- * asb_utils_add_apps_from_dir:
- * @apps: (element-type AsbApp): applications
- * @path: path to read
- * @error: A #GError or %NULL
- *
- * Add applications from a directory.
- *
- * Returns: %TRUE for success, %FALSE otherwise
- *
- * Since: 0.1.0
- **/
-gboolean
-asb_utils_add_apps_from_dir (GList **apps, const gchar *path, GError **error)
-{
-	const gchar *tmp;
-	_cleanup_dir_close_ GDir *dir = NULL;
-
-	dir = g_dir_open (path, 0, error);
-	if (dir == NULL)
-		return FALSE;
-	while ((tmp = g_dir_read_name (dir)) != NULL) {
-		_cleanup_free_ gchar *filename = NULL;
-		filename = g_build_filename (path, tmp, NULL);
-		if (!asb_utils_add_apps_from_file (apps, filename, error))
-			return FALSE;
-	}
-	return TRUE;
-}
-
 /**
  * asb_string_replace:
  * @string: Source string
