@@ -216,26 +216,28 @@ asb_plugin_desktop_add_icons (AsbPlugin *plugin,
 	}
 
 	/* is icon in a unsupported format */
-	if (g_str_has_suffix (fn, ".xpm")) {
-		g_set_error (error,
-			     ASB_PLUGIN_ERROR,
-			     ASB_PLUGIN_ERROR_NOT_SUPPORTED,
-			     "Uses XPM icon: %s", key);
-		return FALSE;
-	}
-	if (g_str_has_suffix (fn, ".gif")) {
-		g_set_error (error,
-			     ASB_PLUGIN_ERROR,
-			     ASB_PLUGIN_ERROR_NOT_SUPPORTED,
-			     "Uses GIF icon: %s", key);
-		return FALSE;
-	}
-	if (g_str_has_suffix (fn, ".ico")) {
-		g_set_error (error,
-			     ASB_PLUGIN_ERROR,
-			     ASB_PLUGIN_ERROR_NOT_SUPPORTED,
-			     "Uses ICO icon: %s", key);
-		return FALSE;
+	if (!asb_context_get_flag (plugin->ctx, ASB_CONTEXT_FLAG_IGNORE_LEGACY_ICONS)) {
+		if (g_str_has_suffix (fn, ".xpm")) {
+			g_set_error (error,
+				     ASB_PLUGIN_ERROR,
+				     ASB_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "Uses XPM icon: %s", key);
+			return FALSE;
+		}
+		if (g_str_has_suffix (fn, ".gif")) {
+			g_set_error (error,
+				     ASB_PLUGIN_ERROR,
+				     ASB_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "Uses GIF icon: %s", key);
+			return FALSE;
+		}
+		if (g_str_has_suffix (fn, ".ico")) {
+			g_set_error (error,
+				     ASB_PLUGIN_ERROR,
+				     ASB_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "Uses ICO icon: %s", key);
+			return FALSE;
+		}
 	}
 
 	/* load the icon */
@@ -258,7 +260,7 @@ asb_plugin_desktop_add_icons (AsbPlugin *plugin,
 	}
 	icon = as_icon_new ();
 	as_icon_set_pixbuf (icon, pixbuf);
-	as_icon_set_name (icon, name, -1);
+	as_icon_set_name (icon, name);
 	as_icon_set_kind (icon, AS_ICON_KIND_CACHED);
 	as_icon_set_prefix (icon, as_app_get_icon_path (AS_APP (app)));
 	as_app_add_icon (AS_APP (app), icon);
@@ -291,7 +293,7 @@ asb_plugin_desktop_add_icons (AsbPlugin *plugin,
 				      as_app_get_id_filename (AS_APP (app)));
 	icon_hidpi = as_icon_new ();
 	as_icon_set_pixbuf (icon_hidpi, pixbuf_hidpi);
-	as_icon_set_name (icon_hidpi, name_hidpi, -1);
+	as_icon_set_name (icon_hidpi, name_hidpi);
 	as_icon_set_kind (icon_hidpi, AS_ICON_KIND_CACHED);
 	as_icon_set_prefix (icon_hidpi, as_app_get_icon_path (AS_APP (app)));
 	as_app_add_icon (AS_APP (app), icon_hidpi);
@@ -310,22 +312,23 @@ asb_plugin_process_filename (AsbPlugin *plugin,
 			     GError **error)
 {
 	AsIcon *icon;
+	AsAppParseFlags parse_flags = AS_APP_PARSE_FLAG_USE_HEURISTICS;
 	gboolean ret;
 	_cleanup_free_ gchar *app_id = NULL;
 	_cleanup_free_ gchar *full_filename = NULL;
 	_cleanup_object_unref_ AsbApp *app = NULL;
 	_cleanup_object_unref_ GdkPixbuf *pixbuf = NULL;
 
+	/* use GenericName fallback */
+	if (asb_context_get_flag (plugin->ctx, ASB_CONTEXT_FLAG_USE_FALLBACKS))
+		parse_flags |= AS_APP_PARSE_FLAG_USE_FALLBACKS;
+
 	/* create app */
 	app_id = g_path_get_basename (filename);
 	app = asb_app_new (pkg, app_id);
 	asb_app_set_hidpi_enabled (app, asb_context_get_flag (plugin->ctx, ASB_CONTEXT_FLAG_HIDPI_ICONS));
 	full_filename = g_build_filename (tmpdir, filename, NULL);
-	ret = as_app_parse_file (AS_APP (app),
-				 full_filename,
-				 AS_APP_PARSE_FLAG_USE_HEURISTICS,
-				 error);
-	if (!ret)
+	if (!as_app_parse_file (AS_APP (app), full_filename, parse_flags, error))
 		return FALSE;
 
 	/* NoDisplay apps are never included */
@@ -333,10 +336,12 @@ asb_plugin_process_filename (AsbPlugin *plugin,
 		asb_app_add_requires_appdata (app, "NoDisplay=true");
 
 	/* Settings or DesktopSettings requires AppData */
-	if (as_app_has_category (AS_APP (app), "Settings"))
-		asb_app_add_requires_appdata (app, "Category=Settings");
-	if (as_app_has_category (AS_APP (app), "DesktopSettings"))
-		asb_app_add_requires_appdata (app, "Category=DesktopSettings");
+	if (!asb_context_get_flag (plugin->ctx, ASB_CONTEXT_FLAG_IGNORE_SETTINGS)) {
+		if (as_app_has_category (AS_APP (app), "Settings"))
+			asb_app_add_requires_appdata (app, "Category=Settings");
+		if (as_app_has_category (AS_APP (app), "DesktopSettings"))
+			asb_app_add_requires_appdata (app, "Category=DesktopSettings");
+	}
 
 	/* is the icon a stock-icon-name? */
 	icon = as_app_get_icon_default (AS_APP (app));
