@@ -109,46 +109,46 @@ asb_plugin_process_app (AsbPlugin *plugin,
 	/* add extra categories */
 	tmp = as_app_get_id (AS_APP (app));
 	if (g_strcmp0 (tmp, "0install.desktop") == 0)
-		as_app_add_category (AS_APP (app), "System", -1);
+		as_app_add_category (AS_APP (app), "System");
 	if (g_strcmp0 (tmp, "alacarte.desktop") == 0)
-		as_app_add_category (AS_APP (app), "System", -1);
+		as_app_add_category (AS_APP (app), "System");
 	if (g_strcmp0 (tmp, "deja-dup.desktop") == 0)
-		as_app_add_category (AS_APP (app), "Utility", -1);
+		as_app_add_category (AS_APP (app), "Utility");
 	if (g_strcmp0 (tmp, "gddccontrol.desktop") == 0)
-		as_app_add_category (AS_APP (app), "System", -1);
+		as_app_add_category (AS_APP (app), "System");
 	if (g_strcmp0 (tmp, "nautilus.desktop") == 0)
-		as_app_add_category (AS_APP (app), "System", -1);
+		as_app_add_category (AS_APP (app), "System");
 	if (g_strcmp0 (tmp, "pessulus.desktop") == 0)
-		as_app_add_category (AS_APP (app), "System", -1);
+		as_app_add_category (AS_APP (app), "System");
 	if (g_strcmp0 (tmp, "pmdefaults.desktop") == 0)
-		as_app_add_category (AS_APP (app), "System", -1);
+		as_app_add_category (AS_APP (app), "System");
 	if (g_strcmp0 (tmp, "fwfstab.desktop") == 0)
-		as_app_add_category (AS_APP (app), "System", -1);
+		as_app_add_category (AS_APP (app), "System");
 	if (g_strcmp0 (tmp, "bmpanel2cfg.desktop") == 0)
-		as_app_add_category (AS_APP (app), "System", -1);
+		as_app_add_category (AS_APP (app), "System");
 	if (g_strcmp0 (tmp, "wallpapoz.desktop") == 0)
-		as_app_add_category (AS_APP (app), "System", -1);
+		as_app_add_category (AS_APP (app), "System");
 	if (g_strcmp0 (tmp, "superkaramba.desktop") == 0)
-		as_app_add_category (AS_APP (app), "System", -1);
+		as_app_add_category (AS_APP (app), "System");
 
 	/* add extra project groups */
 	if (g_strcmp0 (tmp, "nemo.desktop") == 0)
-		as_app_set_project_group (AS_APP (app), "Cinnamon", -1);
+		as_app_set_project_group (AS_APP (app), "Cinnamon");
 	if (g_strcmp0 (tmp, "xfdashboard.desktop") == 0)
-		as_app_set_project_group (AS_APP (app), "XFCE", -1);
+		as_app_set_project_group (AS_APP (app), "XFCE");
 
 	/* use the URL to guess the project group */
 	tmp = asb_package_get_url (pkg);
 	if (as_app_get_project_group (AS_APP (app)) == NULL && tmp != NULL) {
 		tmp = asb_glob_value_search (plugin->priv->project_groups, tmp);
 		if (tmp != NULL)
-			as_app_set_project_group (AS_APP (app), tmp, -1);
+			as_app_set_project_group (AS_APP (app), tmp);
 	}
 
 	/* use summary to guess the project group */
 	tmp = as_app_get_comment (AS_APP (app), NULL);
 	if (tmp != NULL && g_strstr_len (tmp, -1, "for KDE") != NULL)
-		as_app_set_project_group (AS_APP (app), "KDE", -1);
+		as_app_set_project_group (AS_APP (app), "KDE");
 
 	/* look for any installed docs */
 	filelist = asb_package_get_filelist (pkg);
@@ -199,39 +199,41 @@ asb_plugin_process_app (AsbPlugin *plugin,
 	}
 
 	/* look for ancient toolkits */
-	for (i = 0; i < deps->len; i++) {
-		tmp = g_ptr_array_index (deps, i);
-		if (g_strcmp0 (tmp, "libgtk-1.2.so.0") == 0) {
-			as_app_add_veto (AS_APP (app), "Uses obsolete GTK1 toolkit");
-			break;
-		}
-		if (g_strcmp0 (tmp, "libglib-1.2.so.0") == 0) {
-			as_app_add_veto (AS_APP (app), "Uses obsolete GLib library");
-			break;
-		}
-		if (g_strcmp0 (tmp, "libqt-mt.so.3") == 0) {
-			as_app_add_veto (AS_APP (app), "Uses obsolete QT3 toolkit");
-			break;
-		}
-		if (g_strcmp0 (tmp, "liblcms.so.1") == 0) {
-			as_app_add_veto (AS_APP (app), "Uses obsolete LCMS library");
-			break;
-		}
-		if (g_strcmp0 (tmp, "libelektra.so.4") == 0) {
-			as_app_add_veto (AS_APP (app), "Uses obsolete Elektra library");
-			break;
-		}
-		if (g_strcmp0 (tmp, "libXt.so.6") == 0) {
-			asb_app_add_requires_appdata (app, "Uses obsolete X11 toolkit");
-			break;
-		}
-		if (g_strcmp0 (tmp, "Xvfb") == 0) {
-			asb_app_add_requires_appdata (app, "Uses obsolete Xvfb");
-			break;
-		}
-		if (g_strcmp0 (tmp, "wine-core") == 0) {
-			asb_app_add_requires_appdata (app, "Uses wine");
-			break;
+	if (!asb_context_get_flag (plugin->ctx, ASB_CONTEXT_FLAG_IGNORE_OBSOLETE_DEPS)) {
+		for (i = 0; i < deps->len; i++) {
+			tmp = g_ptr_array_index (deps, i);
+			if (g_strcmp0 (tmp, "libgtk-1.2.so.0") == 0) {
+				as_app_add_veto (AS_APP (app), "Uses obsolete GTK1 toolkit");
+				break;
+			}
+			if (g_strcmp0 (tmp, "libglib-1.2.so.0") == 0) {
+				as_app_add_veto (AS_APP (app), "Uses obsolete GLib library");
+				break;
+			}
+			if (g_strcmp0 (tmp, "libqt-mt.so.3") == 0) {
+				as_app_add_veto (AS_APP (app), "Uses obsolete QT3 toolkit");
+				break;
+			}
+			if (g_strcmp0 (tmp, "liblcms.so.1") == 0) {
+				as_app_add_veto (AS_APP (app), "Uses obsolete LCMS library");
+				break;
+			}
+			if (g_strcmp0 (tmp, "libelektra.so.4") == 0) {
+				as_app_add_veto (AS_APP (app), "Uses obsolete Elektra library");
+				break;
+			}
+			if (g_strcmp0 (tmp, "libXt.so.6") == 0) {
+				asb_app_add_requires_appdata (app, "Uses obsolete X11 toolkit");
+				break;
+			}
+			if (g_strcmp0 (tmp, "Xvfb") == 0) {
+				asb_app_add_requires_appdata (app, "Uses obsolete Xvfb");
+				break;
+			}
+			if (g_strcmp0 (tmp, "wine-core") == 0) {
+				asb_app_add_requires_appdata (app, "Uses wine");
+				break;
+			}
 		}
 	}
 
@@ -245,7 +247,7 @@ asb_plugin_process_app (AsbPlugin *plugin,
 			days = secs / (60 * 60 * 24);
 			if (secs > 0 && days < 365) {
 				as_app_add_metadata (AS_APP (app),
-						     "X-Kudo-RecentRelease", "", -1);
+						     "X-Kudo-RecentRelease", "");
 				break;
 			}
 		}
@@ -253,7 +255,8 @@ asb_plugin_process_app (AsbPlugin *plugin,
 
 	/* has there been no upstream version recently */
 	if (releases->len > 0 &&
-	    as_app_get_id_kind (AS_APP (app)) == AS_ID_KIND_DESKTOP) {
+	    as_app_get_id_kind (AS_APP (app)) == AS_ID_KIND_DESKTOP &&
+	    !asb_context_get_flag (plugin->ctx, ASB_CONTEXT_FLAG_IGNORE_DEAD_UPSTREAM)) {
 		release = g_ptr_array_index (releases, 0);
 		secs = (g_get_real_time () / G_USEC_PER_SEC) -
 			as_release_get_timestamp (release);
