@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2014-2015 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -48,7 +48,7 @@ asb_plugin_add_globs (AsbPlugin *plugin, GPtrArray *globs)
 static gboolean
 _asb_plugin_check_filename (const gchar *filename)
 {
-	if (fnmatch ("/usr/share/appdata/*.metainfo.xml", filename, 0) == 0)
+	if (asb_plugin_match_glob ("/usr/share/appdata/*.metainfo.xml", filename))
 		return TRUE;
 	return FALSE;
 }
@@ -89,7 +89,7 @@ asb_plugin_process_filename (AsbPlugin *plugin,
 		return FALSE;
 	}
 	asb_app_set_requires_appdata (app, FALSE);
-	asb_app_set_hidpi_enabled (app, asb_context_get_hidpi_enabled (plugin->ctx));
+	asb_app_set_hidpi_enabled (app, asb_context_get_flag (plugin->ctx, ASB_CONTEXT_FLAG_HIDPI_ICONS));
 	asb_plugin_add_app (apps, AS_APP (app));
 	return TRUE;
 }
