@@ -317,7 +317,9 @@ as_app_validate_description_list (const gchar *text,
 	    helper->para_chars_before_list < (guint) length_para_before_list) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_STYLE_INCORRECT,
-				     "Not enough <p> content before <ul>");
+				     "Content before <ul> is too short [%d], at least %d characters required",
+				     helper->para_chars_before_list,
+				     length_para_before_list);
 	}
 
 	/* we allow the previous paragraph to be short to
@@ -342,9 +344,7 @@ as_app_validate_description (const gchar *xml,
 	_cleanup_node_unref_ GNode *node = NULL;
 
 	/* parse xml */
-	node = as_node_from_xml (xml, -1,
-				 AS_NODE_FROM_XML_FLAG_NONE,
-				 error);
+	node = as_node_from_xml (xml, AS_NODE_FROM_XML_FLAG_NONE, error);
 	if (node == NULL)
 		return FALSE;
 	helper->number_paragraphs = 0;
@@ -1106,10 +1106,13 @@ as_app_validate (AsApp *app, AsAppValidateFlags flags, GError **error)
 				     "<id> has invalid type attribute");
 
 		break;
+	case AS_ID_KIND_FIRMWARE:
+		if (g_str_has_suffix (id, ".firmware"))
+			ret = TRUE;
+		break;
 	case AS_ID_KIND_FONT:
 	case AS_ID_KIND_ADDON:
 	case AS_ID_KIND_SOURCE:
-	case AS_ID_KIND_FIRMWARE:
 		/* anything goes */
 		ret = TRUE;
 	default:
