@@ -560,7 +560,7 @@ as_node_start_element_cb (GMarkupParseContext *context,
 	/* transfer the ownership of the comment to the new child */
 	tmp = as_node_take_attribute (helper->current, "@comment-tmp");
 	if (tmp != NULL) {
-		as_node_add_attribute (current, "@comment", tmp, -1);
+		as_node_add_attribute (current, "@comment", tmp);
 		g_free (tmp);
 	}
 
@@ -667,18 +667,17 @@ as_node_passthrough_cb (GMarkupParseContext *context,
 	/* append together comments */
 	existing = as_node_get_attribute (helper->current, "@comment-tmp");
 	if (existing == NULL) {
-		as_node_add_attribute (helper->current, "@comment-tmp", tmp, -1);
+		as_node_add_attribute (helper->current, "@comment-tmp", tmp);
 	} else {
 		_cleanup_free_ gchar *join = NULL;
 		join = g_strdup_printf ("%s<&>%s", existing, tmp);
-		as_node_add_attribute (helper->current, "@comment-tmp", join, -1);
+		as_node_add_attribute (helper->current, "@comment-tmp", join);
 	}
 }
 
 /**
  * as_node_from_xml: (skip)
  * @data: XML data
- * @data_len: Length of @data, or -1 if NULL terminated
  * @flags: #AsNodeFromXmlFlags, e.g. %AS_NODE_FROM_XML_FLAG_NONE
  * @error: A #GError or %NULL
  *
@@ -690,7 +689,6 @@ as_node_passthrough_cb (GMarkupParseContext *context,
  **/
 GNode *
 as_node_from_xml (const gchar *data,
-		  gssize data_len,
 		  AsNodeFromXmlFlags flags,
 		  GError **error)
 {
@@ -717,7 +715,7 @@ as_node_from_xml (const gchar *data,
 					  NULL);
 	ret = g_markup_parse_context_parse (ctx,
 					    data,
-					    data_len,
+					    -1,
 					    &error_local);
 	if (!ret) {
 		g_set_error_literal (error,
@@ -899,6 +897,8 @@ as_node_get_child_node (const GNode *root, const gchar *name,
 	GNode *node;
 
 	/* invalid */
+	if (root == NULL)
+		return NULL;
 	if (name == NULL || name[0] == '\0')
 		return NULL;
 
@@ -1042,7 +1042,6 @@ as_node_get_tag (const GNode *node)
  * as_node_set_data: (skip)
  * @node: a #GNode
  * @cdata: new data
- * @cdata_len: length of @data, or -1 if NULL terminated
  * @insert_flags: any %AsNodeInsertFlags.
  *
  * Sets new data on a node.
@@ -1052,7 +1051,6 @@ as_node_get_tag (const GNode *node)
 void
 as_node_set_data (GNode *node,
 		  const gchar *cdata,
-		  gssize cdata_len,
 		  AsNodeInsertFlags insert_flags)
 {
 	AsNodeData *data;
@@ -1064,7 +1062,7 @@ as_node_set_data (GNode *node,
 
 	data = (AsNodeData *) node->data;
 	g_free (data->cdata);
-	data->cdata = as_strndup (cdata, cdata_len);
+	data->cdata = g_strdup (cdata);
 	data->cdata_escaped = insert_flags & AS_NODE_INSERT_FLAG_PRE_ESCAPED;
 }
 
@@ -1072,16 +1070,15 @@ as_node_set_data (GNode *node,
  * as_node_set_comment: (skip)
  * @node: a #GNode
  * @comment: new comment
- * @comment_len: length of @data, or -1 if NULL terminated
  *
  * Sets new comment for the node.
  *
  * Since: 0.1.6
  **/
 void
-as_node_set_comment (GNode *node, const gchar *comment, gssize comment_len)
+as_node_set_comment (GNode *node, const gchar *comment)
 {
-	return as_node_add_attribute (node, "@comment", comment, comment_len);
+	return as_node_add_attribute (node, "@comment", comment);
 }
 
 /**
@@ -1230,7 +1227,6 @@ as_node_remove_attribute (GNode *node, const gchar *key)
  * @node: a #GNode
  * @key: the attribute key
  * @value: new data
- * @value_len: length of @data, or -1 if NULL terminated
  *
  * Adds a new attribute to a node.
  *
@@ -1239,8 +1235,7 @@ as_node_remove_attribute (GNode *node, const gchar *key)
 void
 as_node_add_attribute (GNode *node,
 		       const gchar *key,
-		       const gchar *value,
-		       gssize value_len)
+		       const gchar *value)
 {
 	AsNodeData *data;
 	AsNodeAttr *attr;
@@ -1252,7 +1247,7 @@ as_node_add_attribute (GNode *node,
 		return;
 	data = (AsNodeData *) node->data;
 	attr = as_node_attr_insert (data, key, NULL);
-	attr->value = as_strndup (value, value_len);
+	attr->value = g_strdup (value);
 }
 
 /**
@@ -1269,7 +1264,7 @@ void
 as_node_add_attribute_as_int (GNode *node, const gchar *key, gint value)
 {
 	_cleanup_free_ gchar *tmp = g_strdup_printf ("%i", value);
-	as_node_add_attribute (node, key, tmp, -1);
+	as_node_add_attribute (node, key, tmp);
 }
 
 /**
@@ -1461,7 +1456,7 @@ as_node_insert_localized (GNode *parent,
 	data = g_slice_new0 (AsNodeData);
 	as_node_data_set_name (data, name, insert_flags);
 	if (insert_flags & AS_NODE_INSERT_FLAG_NO_MARKUP) {
-		data->cdata = as_markup_convert_simple (value_c, -1, NULL);
+		data->cdata = as_markup_convert_simple (value_c, NULL);
 		data->cdata_escaped = FALSE;
 	} else {
 		data->cdata = g_strdup (value_c);
@@ -1484,7 +1479,7 @@ as_node_insert_localized (GNode *parent,
 		as_node_attr_insert (data, "xml:lang", key);
 		as_node_data_set_name (data, name, insert_flags);
 		if (insert_flags & AS_NODE_INSERT_FLAG_NO_MARKUP) {
-			data->cdata = as_markup_convert_simple (value, -1, NULL);
+			data->cdata = as_markup_convert_simple (value, NULL);
 			data->cdata_escaped = FALSE;
 		} else {
 			data->cdata = g_strdup (value);
