@@ -103,14 +103,16 @@ as_provide_kind_from_string (const gchar *kind)
 		return AS_PROVIDE_KIND_FONT;
 	if (g_strcmp0 (kind, "modalias") == 0)
 		return AS_PROVIDE_KIND_MODALIAS;
-	if (g_strcmp0 (kind, "firmware") == 0)
-		return AS_PROVIDE_KIND_FIRMWARE;
+	if (g_strcmp0 (kind, "firmware-runtime") == 0)
+		return AS_PROVIDE_KIND_FIRMWARE_RUNTIME;
+	if (g_strcmp0 (kind, "firmware-flashed") == 0)
+		return AS_PROVIDE_KIND_FIRMWARE_FLASHED;
 	if (g_strcmp0 (kind, "python2") == 0)
 		return AS_PROVIDE_KIND_PYTHON2;
 	if (g_strcmp0 (kind, "python3") == 0)
 		return AS_PROVIDE_KIND_PYTHON3;
-	if (g_strcmp0 (kind, "dbus") == 0)
-		return AS_PROVIDE_KIND_DBUS;
+	if (g_strcmp0 (kind, "dbus-session") == 0)
+		return AS_PROVIDE_KIND_DBUS_SESSION;
 	if (g_strcmp0 (kind, "dbus-system") == 0)
 		return AS_PROVIDE_KIND_DBUS_SYSTEM;
 	return AS_PROVIDE_KIND_UNKNOWN;
@@ -137,13 +139,15 @@ as_provide_kind_to_string (AsProvideKind kind)
 		return "font";
 	if (kind == AS_PROVIDE_KIND_MODALIAS)
 		return "modalias";
-	if (kind == AS_PROVIDE_KIND_FIRMWARE)
-		return "firmware";
+	if (kind == AS_PROVIDE_KIND_FIRMWARE_RUNTIME)
+		return "firmware-runtime";
+	if (kind == AS_PROVIDE_KIND_FIRMWARE_FLASHED)
+		return "firmware-flashed";
 	if (kind == AS_PROVIDE_KIND_PYTHON2)
 		return "python2";
 	if (kind == AS_PROVIDE_KIND_PYTHON3)
 		return "python3";
-	if (kind == AS_PROVIDE_KIND_DBUS)
+	if (kind == AS_PROVIDE_KIND_DBUS_SESSION)
 		return "dbus";
 	if (kind == AS_PROVIDE_KIND_DBUS_SYSTEM)
 		return "dbus-system";
@@ -188,18 +192,17 @@ as_provide_get_kind (AsProvide *provide)
  * as_provide_set_value:
  * @provide: a #AsProvide instance.
  * @value: the URL.
- * @value_len: the size of @value, or -1 if %NULL-terminated.
  *
  * Sets the fully-qualified mirror URL to use for the provide.
  *
  * Since: 0.1.6
  **/
 void
-as_provide_set_value (AsProvide *provide, const gchar *value, gssize value_len)
+as_provide_set_value (AsProvide *provide, const gchar *value)
 {
 	AsProvidePrivate *priv = GET_PRIVATE (provide);
 	g_free (priv->value);
-	priv->value = as_strndup (value, value_len);
+	priv->value = g_strdup (value);
 }
 
 /**
@@ -239,7 +242,7 @@ as_provide_node_insert (AsProvide *provide, GNode *parent, AsNodeContext *ctx)
 	switch (priv->kind) {
 	case AS_PROVIDE_KIND_UNKNOWN:
 		break;
-	case AS_PROVIDE_KIND_DBUS:
+	case AS_PROVIDE_KIND_DBUS_SESSION:
 		n = as_node_insert (parent, "dbus",
 				    priv->value,
 				    AS_NODE_INSERT_FLAG_NONE,
@@ -253,6 +256,20 @@ as_provide_node_insert (AsProvide *provide, GNode *parent, AsNodeContext *ctx)
 				    "type", "system",
 				    NULL);
 		break;
+	case AS_PROVIDE_KIND_FIRMWARE_FLASHED:
+		n = as_node_insert (parent, "firmware",
+				    priv->value,
+				    AS_NODE_INSERT_FLAG_NONE,
+				    "type", "flashed",
+				    NULL);
+		break;
+	case AS_PROVIDE_KIND_FIRMWARE_RUNTIME:
+		n = as_node_insert (parent, "firmware",
+				    priv->value,
+				    AS_NODE_INSERT_FLAG_NONE,
+				    "type", "runtime",
+				    NULL);
+		break;
 	default:
 		n = as_node_insert (parent, as_provide_kind_to_string (priv->kind),
 				    priv->value,
@@ -301,10 +318,23 @@ as_provide_node_parse (AsProvide *provide, GNode *node,
 		       AsNodeContext *ctx, GError **error)
 {
 	AsProvidePrivate *priv = GET_PRIVATE (provide);
-	priv->kind = as_provide_kind_from_string (as_node_get_name (node));
-	if (priv->kind == AS_PROVIDE_KIND_DBUS &&
-	    g_strcmp0 (as_node_get_attribute (node, "type"), "system") == 0)
-		priv->kind = AS_PROVIDE_KIND_DBUS_SYSTEM;
+	const gchar *tmp;
+
+	if (g_strcmp0 (as_node_get_name (node), "dbus") == 0) {
+		tmp = as_node_get_attribute (node, "type");
+		if (g_strcmp0 (tmp, "system") == 0)
+			priv->kind = AS_PROVIDE_KIND_DBUS_SYSTEM;
+		else
+			priv->kind = AS_PROVIDE_KIND_DBUS_SESSION;
+	} else if (g_strcmp0 (as_node_get_name (node), "firmware") == 0) {
+		tmp = as_node_get_attribute (node, "type");
+		if (g_strcmp0 (tmp, "flashed") == 0)
+			priv->kind = AS_PROVIDE_KIND_FIRMWARE_FLASHED;
+		else
+			priv->kind = AS_PROVIDE_KIND_FIRMWARE_RUNTIME;
+	} else {
+		priv->kind = as_provide_kind_from_string (as_node_get_name (node));
+	}
 	g_free (priv->value);
 	priv->value = as_node_take_data (node);
 	return TRUE;
