@@ -40,11 +40,12 @@
 #include "as-cleanup.h"
 #include "as-node-private.h"
 #include "as-problem.h"
+#include "as-monitor.h"
 #include "as-store.h"
 #include "as-utils-private.h"
 #include "as-yaml.h"
 
-#define AS_API_VERSION_NEWEST	0.6
+#define AS_API_VERSION_NEWEST	0.8
 
 typedef enum {
 	AS_STORE_PROBLEM_NONE			= 0,
@@ -62,11 +63,14 @@ struct _AsStorePrivate
 	GPtrArray		*array;		/* of AsApp */
 	GHashTable		*hash_id;	/* of AsApp{id} */
 	GHashTable		*hash_pkgname;	/* of AsApp{pkgname} */
-	GPtrArray		*file_monitors;	/* of GFileMonitor */
+	AsMonitor		*monitor;
 	GHashTable		*metadata_indexes;	/* GHashTable{key} */
 	AsStoreAddFlags		 add_flags;
+	AsStoreWatchFlags	 watch_flags;
 	AsStoreProblems		 problems;
 	guint32			 filter;
+	guint			 changed_block_refcnt;
+	gboolean		 is_pending_changed_signal;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (AsStore, as_store, G_TYPE_OBJECT)
@@ -109,7 +113,7 @@ as_store_finalize (GObject *object)
 	g_free (priv->origin);
 	g_free (priv->builder_id);
 	g_ptr_array_unref (priv->array);
-	g_ptr_array_unref (priv->file_monitors);
+	g_object_unref (priv->monitor);
 	g_hash_table_unref (priv->hash_id);
 	g_hash_table_unref (priv->hash_pkgname);
 	g_hash_table_unref (priv->metadata_indexes);
@@ -117,30 +121,6 @@ as_store_finalize (GObject *object)
 	G_OBJECT_CLASS (as_store_parent_class)->finalize (object);
 }
 
-/**
- * as_store_init:
- **/
-static void
-as_store_init (AsStore *store)
-{
-	AsStorePrivate *priv = GET_PRIVATE (store);
-	priv->api_version = AS_API_VERSION_NEWEST;
-	priv->array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
-	priv->hash_id = g_hash_table_new_full (g_str_hash,
-					       g_str_equal,
-					       NULL,
-					       NULL);
-	priv->hash_pkgname = g_hash_table_new_full (g_str_hash,
-						    g_str_equal,
-						    g_free,
-						    (GDestroyNotify) g_object_unref);
-	priv->file_monitors = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
-	priv->metadata_indexes = g_hash_table_new_full (g_str_hash,
-							  g_str_equal,
-							  g_free,
-							  (GDestroyNotify) g_hash_table_unref);
-}
-
 /**
  * as_store_class_init:
  **/
@@ -153,8 +133,8 @@ as_store_class_init (AsStoreClass *klass)
 	 * AsStore::changed:
 	 * @device: the #AsStore instance that emitted the signal
 	 *
-	 * The ::changed signal is emitted when the files backing the store
-	 * have changed.
+	 * The ::changed signal is emitted when components have been added
+	 * or removed from the store.
 	 *
 	 * Since: 0.1.2
 	 **/
@@ -168,6 +148,64 @@ as_store_class_init (AsStoreClass *klass)
 	object_class->finalize = as_store_finalize;
 }
 
+/**
+ * as_store_perhaps_emit_changed:
+ */
+static void
+as_store_perhaps_emit_changed (AsStore *store, const gchar *details)
+{
+	AsStorePrivate *priv = GET_PRIVATE (store);
+	if (priv->changed_block_refcnt > 0) {
+		priv->is_pending_changed_signal = TRUE;
+		return;
+	}
+	if (!priv->is_pending_changed_signal) {
+		priv->is_pending_changed_signal = TRUE;
+		return;
+	}
+	g_debug ("Emitting ::changed() [%s]", details);
+	g_signal_emit (store, signals[SIGNAL_CHANGED], 0);
+	priv->is_pending_changed_signal = FALSE;
+}
+
+/**
+ * as_store_changed_inhibit:
+ */
+static guint32 *
+as_store_changed_inhibit (AsStore *store)
+{
+	AsStorePrivate *priv = GET_PRIVATE (store);
+	priv->changed_block_refcnt++;
+	return &priv->changed_block_refcnt;
+}
+
+/**
+ * as_store_changed_uninhibit:
+ */
+static void
+as_store_changed_uninhibit (guint32 **tok)
+{
+	if (tok == NULL || *tok == NULL)
+		return;
+	if (*(*tok) == 0) {
+		g_critical ("changed_block_refcnt already zero");
+		return;
+	}
+	(*(*tok))--;
+	*tok = NULL;
+}
+
+/**
+ * as_store_changed_uninhibit_cb:
+ */
+static void
+as_store_changed_uninhibit_cb (void *v)
+{
+	as_store_changed_uninhibit ((guint32 **)v);
+}
+
+#define _cleanup_uninhibit_ __attribute__ ((cleanup(as_store_changed_uninhibit_cb)))
+
 /**
  * as_store_add_filter:
  * @store: a #AsStore instance.
@@ -390,6 +428,157 @@ as_store_get_app_by_id (AsStore *store, const gchar *id)
 	return g_hash_table_lookup (priv->hash_id, id);
 }
 
+/**
+ * as_store_get_app_by_provide:
+ * @store: a #AsStore instance.
+ * @kind: the #AsProvideKind
+ * @value: the provide value, e.g. "com.hughski.ColorHug2.firmware"
+ *
+ * Finds an application in the store by something that it provides.
+ *
+ * Returns: (transfer none): a #AsApp or %NULL
+ *
+ * Since: 0.5.0
+ **/
+AsApp *
+as_store_get_app_by_provide (AsStore *store, AsProvideKind kind, const gchar *value)
+{
+	AsApp *app;
+	AsProvide *tmp;
+	AsStorePrivate *priv = GET_PRIVATE (store);
+	guint i;
+	guint j;
+	GPtrArray *provides;
+
+	g_return_val_if_fail (AS_IS_STORE (store), NULL);
+	g_return_val_if_fail (kind != AS_PROVIDE_KIND_UNKNOWN, NULL);
+	g_return_val_if_fail (value != NULL, NULL);
+
+	/* find an application that provides something */
+	for (i = 0; i < priv->array->len; i++) {
+		app = g_ptr_array_index (priv->array, i);
+		provides = as_app_get_provides (app);
+		for (j = 0; j < provides->len; j++) {
+			tmp = g_ptr_array_index (provides, j);
+			if (kind != as_provide_get_kind (tmp))
+				continue;
+			if (g_strcmp0 (as_provide_get_value (tmp), value) != 0)
+				continue;
+			return app;
+		}
+	}
+	return NULL;
+
+}
+
+/**
+ * as_store_get_app_by_id_with_fallbacks:
+ * @store: a #AsStore instance.
+ * @id: the application full ID.
+ *
+ * Finds an application in the store by either by the current desktop ID
+ * or a desktop ID that it has used previously. This allows upstream software
+ * to change their ID (e.g. from cheese.desktop to org.gnome.Cheese.desktop)
+ * without us duplicating entries in the software center.
+ *
+ * Returns: (transfer none): a #AsApp or %NULL
+ *
+ * Since: 0.4.1
+ **/
+AsApp *
+as_store_get_app_by_id_with_fallbacks (AsStore *store, const gchar *id)
+{
+	AsApp *app;
+	guint i;
+	const struct {
+		const gchar	*old;
+		const gchar	*new;
+	} id_map[] = {
+		/* GNOME */
+		{ "baobab.desktop",		"org.gnome.baobab.desktop" },
+		{ "cheese.desktop",		"org.gnome.Cheese.desktop" },
+		{ "devhelp.desktop",		"org.gnome.Devhelp.desktop" },
+		{ "file-roller.desktop",	"org.gnome.FileRoller.desktop" },
+		{ "gcalctool.desktop",		"gnome-calculator.desktop" },
+		{ "gedit.desktop",		"org.gnome.gedit.desktop" },
+		{ "glchess.desktop",		"gnome-chess.desktop" },
+		{ "glines.desktop",		"five-or-more.desktop" },
+		{ "gnect.desktop",		"four-in-a-row.desktop" },
+		{ "gnibbles.desktop",		"gnome-nibbles.desktop" },
+		{ "gnobots2.desktop",		"gnome-robots.desktop" },
+		{ "gnome-2048.desktop",		"org.gnome.gnome-2048.desktop" },
+		{ "gnome-boxes.desktop",	"org.gnome.Boxes.desktop" },
+		{ "gnome-clocks.desktop",	"org.gnome.clocks.desktop" },
+		{ "gnome-contacts.desktop",	"org.gnome.Contacts.desktop" },
+		{ "gnome-dictionary.desktop",	"org.gnome.Dictionary.desktop" },
+		{ "gnome-disks.desktop",	"org.gnome.DiskUtility.desktop" },
+		{ "gnome-documents.desktop",	"org.gnome.Documents.desktop" },
+		{ "gnome-font-viewer.desktop",	"org.gnome.font-viewer.desktop" },
+		{ "gnome-maps.desktop",		"org.gnome.Maps.desktop" },
+		{ "gnome-photos.desktop",	"org.gnome.Photos.desktop" },
+		{ "gnome-screenshot.desktop",	"org.gnome.Screenshot.desktop" },
+		{ "gnome-software.desktop",	"org.gnome.Software.desktop" },
+		{ "gnome-sound-recorder.desktop", "org.gnome.SoundRecorder.desktop" },
+		{ "gnome-terminal.desktop",	"org.gnome.Terminal.desktop" },
+		{ "gnome-weather.desktop",	"org.gnome.Weather.Application.desktop" },
+		{ "gnomine.desktop",		"gnome-mines.desktop" },
+		{ "gnotravex.desktop",		"gnome-tetravex.desktop" },
+		{ "gnotski.desktop",		"gnome-klotski.desktop" },
+		{ "gtali.desktop",		"tali.desktop" },
+		{ "nautilus.desktop",		"org.gnome.Nautilus.desktop" },
+		{ "polari.desktop",		"org.gnome.Polari.desktop" },
+		{ "totem.desktop",		"org.gnome.Totem.desktop" },
+
+		/* KDE */
+		{ "blinken.desktop",		"org.kde.blinken.desktop" },
+		{ "cantor.desktop",		"org.kde.cantor.desktop" },
+		{ "filelight.desktop",		"org.kde.filelight.desktop" },
+		{ "gwenview.desktop",		"org.kde.gwenview.desktop" },
+		{ "kalgebra.desktop",		"org.kde.kalgebra.desktop" },
+		{ "kanagram.desktop",		"org.kde.kanagram.desktop" },
+		{ "kapman.desktop",		"org.kde.kapman.desktop" },
+		{ "kbruch.desktop",		"org.kde.kbruch.desktop" },
+		{ "kgeography.desktop",		"org.kde.kgeography.desktop" },
+		{ "khangman.desktop",		"org.kde.khangman.desktop" },
+		{ "kiten.desktop",		"org.kde.kiten.desktop" },
+		{ "klettres.desktop",		"org.kde.klettres.desktop" },
+		{ "klipper.desktop",		"org.kde.klipper.desktop" },
+		{ "kmplot.desktop",		"org.kde.kmplot.desktop" },
+		{ "kollision.desktop",		"org.kde.kollision.desktop" },
+		{ "konsole.desktop",		"org.kde.konsole.desktop" },
+		{ "kstars.desktop",		"org.kde.kstars.desktop" },
+		{ "ktp-log-viewer.desktop",	"org.kde.ktplogviewer.desktop" },
+		{ "kturtle.desktop",		"org.kde.kturtle.desktop" },
+		{ "kwordquiz.desktop",		"org.kde.kwordquiz.desktop" },
+		{ "okteta.desktop",		"org.kde.okteta.desktop" },
+		{ "parley.desktop",		"org.kde.parley.desktop" },
+		{ "partitionmanager.desktop",	"org.kde.PartitionManager.desktop" },
+		{ "step.desktop",		"org.kde.step.desktop" },
+
+		/* others */
+		{ "colorhug-ccmx.desktop",	"com.hughski.ColorHug.CcmxLoader.desktop" },
+		{ "colorhug-flash.desktop",	"com.hughski.ColorHug.FlashLoader.desktop" },
+		{ "dconf-editor.desktop",	"ca.desrt.dconf-editor.desktop" },
+
+		{ NULL, NULL }
+	};
+
+	/* trivial case */
+	app = as_store_get_app_by_id (store, id);
+	if (app != NULL)
+		return app;
+
+	/* has the application ID been renamed */
+	for (i = 0; id_map[i].old != NULL; i++) {
+		if (g_strcmp0 (id, id_map[i].old) == 0)
+			return as_store_get_app_by_id (store, id_map[i].new);
+		if (g_strcmp0 (id, id_map[i].new) == 0)
+			return as_store_get_app_by_id (store, id_map[i].old);
+	}
+
+	return NULL;
+}
+
 /**
  * as_store_get_app_by_pkgname:
  * @store: a #AsStore instance.
@@ -409,6 +598,35 @@ as_store_get_app_by_pkgname (AsStore *store, const gchar *pkgname)
 	return g_hash_table_lookup (priv->hash_pkgname, pkgname);
 }
 
+/**
+ * as_store_get_app_by_pkgnames:
+ * @store: a #AsStore instance.
+ * @pkgnames: the package names to find.
+ *
+ * Finds an application in the store by any of the possible package names.
+ *
+ * Returns: (transfer none): a #AsApp or %NULL
+ *
+ * Since: 0.4.1
+ **/
+AsApp *
+as_store_get_app_by_pkgnames (AsStore *store, gchar **pkgnames)
+{
+	AsApp *app;
+	AsStorePrivate *priv = GET_PRIVATE (store);
+	guint i;
+
+	g_return_val_if_fail (AS_IS_STORE (store), NULL);
+	g_return_val_if_fail (pkgnames != NULL, NULL);
+
+	for (i = 0; pkgnames[i] != NULL; i++) {
+		app = g_hash_table_lookup (priv->hash_pkgname, pkgnames[i]);
+		if (app != NULL)
+			return app;
+	}
+	return NULL;
+}
+
 /**
  * as_store_remove_app:
  * @store: a #AsStore instance.
@@ -425,6 +643,9 @@ as_store_remove_app (AsStore *store, AsApp *app)
 	g_hash_table_remove (priv->hash_id, as_app_get_id (app));
 	g_ptr_array_remove (priv->array, app);
 	g_hash_table_remove_all (priv->metadata_indexes);
+
+	/* removed */
+	as_store_perhaps_emit_changed (store, "remove-app");
 }
 
 /**
@@ -452,6 +673,9 @@ as_store_remove_app_by_id (AsStore *store, const gchar *id)
 		g_ptr_array_remove (priv->array, app);
 	}
 	g_hash_table_remove_all (priv->metadata_indexes);
+
+	/* removed */
+	as_store_perhaps_emit_changed (store, "remove-app-by-id");
 }
 
 /**
@@ -576,6 +800,9 @@ as_store_add_app (AsStore *store, AsApp *app)
 				     g_strdup (pkgname),
 				     g_object_ref (app));
 	}
+
+	/* added */
+	as_store_perhaps_emit_changed (store, "add-app");
 }
 
 /**
@@ -619,6 +846,7 @@ static gboolean
 as_store_from_root (AsStore *store,
 		    GNode *root,
 		    const gchar *icon_root,
+		    const gchar *source_filename,
 		    GError **error)
 {
 	AsStorePrivate *priv = GET_PRIVATE (store);
@@ -627,9 +855,13 @@ as_store_from_root (AsStore *store,
 	const gchar *tmp;
 	_cleanup_free_ AsNodeContext *ctx = NULL;
 	_cleanup_free_ gchar *icon_path = NULL;
+	_cleanup_uninhibit_ guint32 *tok = NULL;
 
 	g_return_val_if_fail (AS_IS_STORE (store), FALSE);
 
+	/* emit once when finished */
+	tok = as_store_changed_inhibit (store);
+
 	apps = as_node_find (root, "components");
 	if (apps == NULL) {
 		apps = as_node_find (root, "applications");
@@ -670,7 +902,7 @@ as_store_from_root (AsStore *store,
 	for (n = apps->children; n != NULL; n = n->next) {
 		_cleanup_error_free_ GError *error_local = NULL;
 		_cleanup_object_unref_ AsApp *app = NULL;
-		if (as_node_get_tag (n) != AS_TAG_APPLICATION)
+		if (as_node_get_tag (n) != AS_TAG_COMPONENT)
 			continue;
 
 		/* do the filtering here */
@@ -686,7 +918,7 @@ as_store_from_root (AsStore *store,
 
 		app = as_app_new ();
 		if (icon_path != NULL)
-			as_app_set_icon_path (app, icon_path, -1);
+			as_app_set_icon_path (app, icon_path);
 		as_app_set_source_kind (app, AS_APP_SOURCE_KIND_APPSTREAM);
 		if (!as_app_node_parse (app, n, ctx, &error_local)) {
 			g_set_error (error,
@@ -697,12 +929,18 @@ as_store_from_root (AsStore *store,
 			return FALSE;
 		}
 		as_app_set_origin (app, priv->origin);
+		if (source_filename != NULL)
+			as_app_set_source_file (app, source_filename);
 		as_store_add_app (store, app);
 	}
 
 	/* add addon kinds to their parent AsApp */
 	as_store_match_addons (store);
 
+	/* this store has changed */
+	as_store_changed_uninhibit (&tok);
+	as_store_perhaps_emit_changed (store, "from-root");
+
 	return TRUE;
 }
 
@@ -723,6 +961,7 @@ as_store_load_yaml_file (AsStore *store,
 	_cleanup_free_ AsNodeContext *ctx = NULL;
 	_cleanup_free_ gchar *icon_path = NULL;
 	_cleanup_yaml_unref_ GNode *root = NULL;
+	_cleanup_uninhibit_ guint32 *tok = NULL;
 
 	/* load file */
 	root = as_yaml_from_file (file, cancellable, error);
@@ -752,6 +991,9 @@ as_store_load_yaml_file (AsStore *store,
 					      NULL);
 	}
 
+	/* emit once when finished */
+	tok = as_store_changed_inhibit (store);
+
 	/* parse applications */
 	ctx = as_node_context_new ();
 	for (app_n = root->children->next; app_n != NULL; app_n = app_n->next) {
@@ -760,7 +1002,7 @@ as_store_load_yaml_file (AsStore *store,
 			continue;
 		app = as_app_new ();
 		if (icon_path != NULL)
-			as_app_set_icon_path (app, icon_path, -1);
+			as_app_set_icon_path (app, icon_path);
 		as_app_set_source_kind (app, AS_APP_SOURCE_KIND_APPSTREAM);
 		if (!as_app_node_parse_dep11 (app, app_n, ctx, error))
 			return FALSE;
@@ -768,9 +1010,112 @@ as_store_load_yaml_file (AsStore *store,
 		if (as_app_get_id (app) != NULL)
 			as_store_add_app (store, app);
 	}
+
+	/* emit changed */
+	as_store_changed_uninhibit (&tok);
+	as_store_perhaps_emit_changed (store, "yaml-file");
+
 	return TRUE;
 }
 
+/**
+ * as_store_remove_by_source_file:
+ */
+static void
+as_store_remove_by_source_file (AsStore *store, const gchar *filename)
+{
+	AsApp *app;
+	GPtrArray *apps;
+	guint i;
+	const gchar *tmp;
+	_cleanup_ptrarray_unref_ GPtrArray *ids = NULL;
+
+	/* find any applications in the store with this source file */
+	ids = g_ptr_array_new_with_free_func (g_free);
+	apps = as_store_get_apps (store);
+	for (i = 0; i < apps->len; i++) {
+		app = g_ptr_array_index (apps, i);
+		if (g_strcmp0 (as_app_get_source_file (app), filename) != 0)
+			continue;
+		g_ptr_array_add (ids, g_strdup (as_app_get_id (app)));
+	}
+
+	/* remove these from the store */
+	for (i = 0; i < ids->len; i++) {
+		tmp = g_ptr_array_index (ids, i);
+		g_debug ("removing %s as %s invalid", tmp, filename);
+		as_store_remove_app_by_id (store, tmp);
+	}
+
+	/* the store changed */
+	as_store_perhaps_emit_changed (store, "remove-by-source-file");
+}
+
+/**
+ * as_store_monitor_changed_cb:
+ */
+static void
+as_store_monitor_changed_cb (AsMonitor *monitor,
+			     const gchar *filename,
+			     AsStore *store)
+{
+	AsStorePrivate *priv = GET_PRIVATE (store);
+
+	/* reload, or emit a signal */
+	if (priv->watch_flags & AS_STORE_WATCH_FLAG_ADDED) {
+		_cleanup_error_free_ GError *error = NULL;
+		_cleanup_object_unref_ GFile *file = NULL;
+		_cleanup_uninhibit_ guint32 *tok = NULL;
+		tok = as_store_changed_inhibit (store);
+		as_store_remove_by_source_file (store, filename);
+		g_debug ("rescanning %s", filename);
+		file = g_file_new_for_path (filename);
+		if (!as_store_from_file (store, file, NULL, NULL, &error))
+			g_warning ("failed to rescan: %s", error->message);
+	}
+	as_store_perhaps_emit_changed (store, "file changed");
+}
+
+/**
+ * as_store_monitor_added_cb:
+ */
+static void
+as_store_monitor_added_cb (AsMonitor *monitor,
+			     const gchar *filename,
+			     AsStore *store)
+{
+	AsStorePrivate *priv = GET_PRIVATE (store);
+
+	/* reload, or emit a signal */
+	if (priv->watch_flags & AS_STORE_WATCH_FLAG_ADDED) {
+		_cleanup_error_free_ GError *error = NULL;
+		_cleanup_object_unref_ GFile *file = NULL;
+		g_debug ("scanning %s", filename);
+		file = g_file_new_for_path (filename);
+		if (!as_store_from_file (store, file, NULL, NULL, &error))
+			g_warning ("failed to rescan: %s", error->message);
+	} else {
+		as_store_perhaps_emit_changed (store, "file added");
+	}
+}
+
+/**
+ * as_store_monitor_removed_cb:
+ */
+static void
+as_store_monitor_removed_cb (AsMonitor *monitor,
+			     const gchar *filename,
+			     AsStore *store)
+{
+	AsStorePrivate *priv = GET_PRIVATE (store);
+	/* remove, or emit a signal */
+	if (priv->watch_flags & AS_STORE_WATCH_FLAG_REMOVED) {
+		as_store_remove_by_source_file (store, filename);
+	} else {
+		as_store_perhaps_emit_changed (store, "file removed");
+	}
+}
+
 /**
  * as_store_from_file:
  * @store: a #AsStore instance.
@@ -797,6 +1142,7 @@ as_store_from_file (AsStore *store,
 		    GCancellable *cancellable,
 		    GError **error)
 {
+	AsStorePrivate *priv = GET_PRIVATE (store);
 	_cleanup_free_ gchar *filename = NULL;
 	_cleanup_error_free_ GError *error_local = NULL;
 	_cleanup_node_unref_ GNode *root = NULL;
@@ -822,14 +1168,23 @@ as_store_from_file (AsStore *store,
 			     filename, error_local->message);
 		return FALSE;
 	}
-	return as_store_from_root (store, root, icon_root, error);
+
+	/* watch for file changes */
+	if (priv->watch_flags > 0) {
+		if (!as_monitor_add_file (priv->monitor,
+					  filename,
+					  cancellable,
+					  error))
+			return FALSE;
+	}
+
+	return as_store_from_root (store, root, icon_root, filename, error);
 }
 
 /**
  * as_store_from_xml:
  * @store: a #AsStore instance.
  * @data: XML data
- * @data_len: Length of @data, or -1 if NULL terminated
  * @icon_root: the icon path, or %NULL for the default.
  * @error: A #GError or %NULL.
  *
@@ -846,7 +1201,6 @@ as_store_from_file (AsStore *store,
 gboolean
 as_store_from_xml (AsStore *store,
 		   const gchar *data,
-		   gssize data_len,
 		   const gchar *icon_root,
 		   GError **error)
 {
@@ -855,7 +1209,7 @@ as_store_from_xml (AsStore *store,
 
 	g_return_val_if_fail (AS_IS_STORE (store), FALSE);
 
-	root = as_node_from_xml (data, data_len,
+	root = as_node_from_xml (data,
 				 AS_NODE_FROM_XML_FLAG_LITERAL_TEXT,
 				 &error_local);
 	if (root == NULL) {
@@ -866,7 +1220,7 @@ as_store_from_xml (AsStore *store,
 			     error_local->message);
 		return TRUE;
 	}
-	return as_store_from_root (store, root, icon_root, error);
+	return as_store_from_root (store, root, icon_root, NULL, error);
 }
 
 /**
@@ -904,25 +1258,21 @@ as_store_to_xml (AsStore *store, AsNodeToXmlFlags flags)
 
 	/* get XML text */
 	node_root = as_node_new ();
-	if (priv->api_version >= 0.6) {
-		node_apps = as_node_insert (node_root, "components", NULL, 0, NULL);
-	} else {
-		node_apps = as_node_insert (node_root, "applications", NULL, 0, NULL);
-	}
+	node_apps = as_node_insert (node_root, "components", NULL, 0, NULL);
 
 	/* set origin attribute */
 	if (priv->origin != NULL)
-		as_node_add_attribute (node_apps, "origin", priv->origin, -1);
+		as_node_add_attribute (node_apps, "origin", priv->origin);
 
 	/* set origin attribute */
 	if (priv->builder_id != NULL)
-		as_node_add_attribute (node_apps, "builder_id", priv->builder_id, -1);
+		as_node_add_attribute (node_apps, "builder_id", priv->builder_id);
 
 	/* set version attribute */
 	if (priv->api_version > 0.1f) {
 		g_ascii_formatd (version, sizeof (version),
 				 "%.1f", priv->api_version);
-		as_node_add_attribute (node_apps, "version", version, -1);
+		as_node_add_attribute (node_apps, "version", version);
 	}
 
 	/* sort by ID */
@@ -1234,6 +1584,39 @@ as_store_set_add_flags (AsStore *store, AsStoreAddFlags add_flags)
 	priv->add_flags = add_flags;
 }
 
+/**
+ * as_store_get_watch_flags:
+ * @store: a #AsStore instance.
+ *
+ * Gets the flags used for adding files to the store.
+ *
+ * Returns: the #AsStoreWatchFlags, or 0 if unset
+ *
+ * Since: 0.4.2
+ **/
+AsStoreWatchFlags
+as_store_get_watch_flags (AsStore *store)
+{
+	AsStorePrivate *priv = GET_PRIVATE (store);
+	return priv->watch_flags;
+}
+
+/**
+ * as_store_set_watch_flags:
+ * @store: a #AsStore instance.
+ * @watch_flags: the #AsStoreWatchFlags, e.g. %AS_STORE_WATCH_FLAG_NONE
+ *
+ * Sets the flags used when adding files to the store.
+ *
+ * Since: 0.4.2
+ **/
+void
+as_store_set_watch_flags (AsStore *store, AsStoreWatchFlags watch_flags)
+{
+	AsStorePrivate *priv = GET_PRIVATE (store);
+	priv->watch_flags = watch_flags;
+}
+
 /**
  * as_store_guess_origin_fallback:
  */
@@ -1295,53 +1678,6 @@ as_store_load_app_info_file (AsStore *store,
 				   error);
 }
 
-/**
- * as_store_cache_changed_cb:
- */
-static void
-as_store_cache_changed_cb (GFileMonitor *monitor,
-			   GFile *file, GFile *other_file,
-			   GFileMonitorEvent event_type,
-			   AsStore *store)
-{
-	g_debug ("Emitting ::changed()");
-	g_signal_emit (store, signals[SIGNAL_CHANGED], 0);
-}
-
-/**
- * as_store_monitor_directory:
- **/
-static gboolean
-as_store_monitor_directory (AsStore *store,
-			    const gchar *path,
-			    GCancellable *cancellable,
-			    GError **error)
-{
-	AsStorePrivate *priv = GET_PRIVATE (store);
-	_cleanup_error_free_ GError *error_local = NULL;
-	_cleanup_object_unref_ GFile *file = NULL;
-	_cleanup_object_unref_ GFileMonitor *monitor = NULL;
-
-	file = g_file_new_for_path (path);
-	monitor = g_file_monitor_directory (file,
-					    G_FILE_MONITOR_NONE,
-					    cancellable,
-					    &error_local);
-	if (monitor == NULL) {
-		g_set_error (error,
-			     AS_STORE_ERROR,
-			     AS_STORE_ERROR_FAILED,
-			     "Failed to monitor %s: %s",
-			     path, error_local->message);
-		return FALSE;
-	}
-	g_signal_connect (monitor, "changed",
-			  G_CALLBACK (as_store_cache_changed_cb),
-			  store);
-	g_ptr_array_add (priv->file_monitors, g_object_ref (monitor));
-	return TRUE;
-}
-
 /**
  * as_store_load_app_info:
  **/
@@ -1352,11 +1688,16 @@ as_store_load_app_info (AsStore *store,
 			GCancellable *cancellable,
 			GError **error)
 {
+	AsStorePrivate *priv = GET_PRIVATE (store);
 	const gchar *tmp;
 	_cleanup_dir_close_ GDir *dir = NULL;
 	_cleanup_error_free_ GError *error_local = NULL;
 	_cleanup_free_ gchar *icon_root = NULL;
 	_cleanup_free_ gchar *path_md = NULL;
+	_cleanup_uninhibit_ guint32 *tok = NULL;
+
+	/* emit once when finished */
+	tok = as_store_changed_inhibit (store);
 
 	/* search all files */
 	path_md = g_build_filename (path, format, NULL);
@@ -1384,11 +1725,16 @@ as_store_load_app_info (AsStore *store,
 	}
 
 	/* watch the directories for changes */
-	if (!as_store_monitor_directory (store, path_md, cancellable, error))
-		return FALSE;
-	if (!as_store_monitor_directory (store, icon_root, cancellable, error))
+	if (!as_monitor_add_directory (priv->monitor,
+				       path_md,
+				       cancellable,
+				       error))
 		return FALSE;
 
+	/* emit changed */
+	as_store_changed_uninhibit (&tok);
+	as_store_perhaps_emit_changed (store, "load-app-info");
+
 	return TRUE;
 }
 
@@ -1414,7 +1760,7 @@ as_store_add_app_install_screenshot (AsApp *app)
 
 	/* screenshots.debian.net doesn't specify a size, so this is a guess */
 	im = as_image_new ();
-	as_image_set_url (im, url, -1);
+	as_image_set_url (im, url);
 	as_image_set_width (im, 800);
 	as_image_set_height (im, 600);
 
@@ -1440,7 +1786,7 @@ as_store_load_app_install_file (AsStore *store,
 	_cleanup_object_unref_ AsApp *app = NULL;
 
 	app = as_app_new ();
-	as_app_set_icon_path (app, path_icons, -1);
+	as_app_set_icon_path (app, path_icons);
 	if (!as_app_parse_file (app,
 				filename,
 				AS_APP_PARSE_FLAG_USE_HEURISTICS,
@@ -1536,11 +1882,15 @@ as_store_load_installed (AsStore *store,
 	GError *error_local = NULL;
 	const gchar *tmp;
 	_cleanup_dir_close_ GDir *dir = NULL;
+	_cleanup_uninhibit_ guint32 *tok = NULL;
 
 	dir = g_dir_open (path, 0, error);
 	if (dir == NULL)
 		return FALSE;
 
+	/* emit once when finished */
+	tok = as_store_changed_inhibit (store);
+
 	/* relax the checks when parsing */
 	if (flags & AS_STORE_LOAD_FLAG_ALLOW_VETO)
 		parse_flags |= AS_APP_PARSE_FLAG_ALLOW_VETO;
@@ -1586,6 +1936,11 @@ as_store_load_installed (AsStore *store,
 		as_app_set_state (app, AS_APP_STATE_INSTALLED);
 		as_store_add_app (store, app);
 	}
+
+	/* emit changed */
+	as_store_changed_uninhibit (&tok);
+	as_store_perhaps_emit_changed (store, "load-installed");
+
 	return TRUE;
 }
 
@@ -1629,6 +1984,7 @@ as_store_load (AsStore *store,
 	       GCancellable *cancellable,
 	       GError **error)
 {
+	/* load from multiple locations */
 	AsStorePrivate *priv = GET_PRIVATE (store);
 	const gchar * const * data_dirs;
 	const gchar *tmp;
@@ -1636,6 +1992,7 @@ as_store_load (AsStore *store,
 	guint i;
 	_cleanup_ptrarray_unref_ GPtrArray *app_info = NULL;
 	_cleanup_ptrarray_unref_ GPtrArray *installed = NULL;
+	_cleanup_uninhibit_ guint32 *tok = NULL;
 
 	/* system locations */
 	app_info = g_ptr_array_new_with_free_func (g_free);
@@ -1645,10 +2002,6 @@ as_store_load (AsStore *store,
 		if ((flags & AS_STORE_LOAD_FLAG_APP_INFO_SYSTEM) > 0) {
 			path = g_build_filename (data_dirs[i], "app-info", NULL);
 			g_ptr_array_add (app_info, path);
-			path = g_build_filename (LOCALSTATEDIR, "lib", "app-info", NULL);
-			g_ptr_array_add (app_info, path);
-			path = g_build_filename (LOCALSTATEDIR, "cache", "app-info", NULL);
-			g_ptr_array_add (app_info, path);
 		}
 		if ((flags & AS_STORE_LOAD_FLAG_APPDATA) > 0) {
 			path = g_build_filename (data_dirs[i], "appdata", NULL);
@@ -1659,6 +2012,20 @@ as_store_load (AsStore *store,
 			g_ptr_array_add (installed, path);
 		}
 	}
+	if ((flags & AS_STORE_LOAD_FLAG_APP_INFO_SYSTEM) > 0) {
+		path = g_build_filename (LOCALSTATEDIR, "lib", "app-info", NULL);
+		g_ptr_array_add (app_info, path);
+		path = g_build_filename (LOCALSTATEDIR, "cache", "app-info", NULL);
+		g_ptr_array_add (app_info, path);
+		/* ignore the prefix; we actually want to use the
+		 * distro-provided data in this case. */
+		if (g_strcmp0 (LOCALSTATEDIR, "/var") != 0) {
+			path = g_build_filename ("/var", "lib", "app-info", NULL);
+			g_ptr_array_add (app_info, path);
+			path = g_build_filename ("/var", "cache", "app-info", NULL);
+			g_ptr_array_add (app_info, path);
+		}
+	}
 
 	/* per-user locations */
 	if ((flags & AS_STORE_LOAD_FLAG_APP_INFO_USER) > 0) {
@@ -1675,6 +2042,7 @@ as_store_load (AsStore *store,
 	}
 
 	/* load each app-info path if it exists */
+	tok = as_store_changed_inhibit (store);
 	for (i = 0; i < app_info->len; i++) {
 		_cleanup_free_ gchar *dest = NULL;
 		tmp = g_ptr_array_index (app_info, i);
@@ -1710,6 +2078,9 @@ as_store_load (AsStore *store,
 	/* match again, for applications extended from different roots */
 	as_store_match_addons (store);
 
+	/* emit changed */
+	as_store_changed_uninhibit (&tok);
+	as_store_perhaps_emit_changed (store, "store-load");
 	return TRUE;
 }
 
@@ -1952,6 +2323,40 @@ as_store_validate (AsStore *store, AsAppValidateFlags flags, GError **error)
 	return probs;
 }
 
+/**
+ * as_store_init:
+ **/
+static void
+as_store_init (AsStore *store)
+{
+	AsStorePrivate *priv = GET_PRIVATE (store);
+	priv->api_version = AS_API_VERSION_NEWEST;
+	priv->array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+	priv->watch_flags = AS_STORE_WATCH_FLAG_NONE;
+	priv->hash_id = g_hash_table_new_full (g_str_hash,
+					       g_str_equal,
+					       NULL,
+					       NULL);
+	priv->hash_pkgname = g_hash_table_new_full (g_str_hash,
+						    g_str_equal,
+						    g_free,
+						    (GDestroyNotify) g_object_unref);
+	priv->monitor = as_monitor_new ();
+	g_signal_connect (priv->monitor, "changed",
+			  G_CALLBACK (as_store_monitor_changed_cb),
+			  store);
+	g_signal_connect (priv->monitor, "added",
+			  G_CALLBACK (as_store_monitor_added_cb),
+			  store);
+	g_signal_connect (priv->monitor, "removed",
+			  G_CALLBACK (as_store_monitor_removed_cb),
+			  store);
+	priv->metadata_indexes = g_hash_table_new_full (g_str_hash,
+							  g_str_equal,
+							  g_free,
+							  (GDestroyNotify) g_hash_table_unref);
+}
+
 /**
  * as_store_new:
  *
