@@ -101,6 +101,22 @@ typedef enum {
 	AS_STORE_ADD_FLAG_LAST
 } AsStoreAddFlags;
 
+/**
+ * AsStoreWatchFlags:
+ * @AS_STORE_WATCH_FLAG_NONE:			No extra flags to use
+ * @AS_STORE_WATCH_FLAG_ADDED:			Add applications if files change or are added
+ * @AS_STORE_WATCH_FLAG_REMOVED:		Remove applications if files are changed or deleted
+ *
+ * The flags to use when local files are added or removed from the store.
+ **/
+typedef enum {
+	AS_STORE_WATCH_FLAG_NONE			= 0,	/* Since: 0.4.2 */
+	AS_STORE_WATCH_FLAG_ADDED			= 1,	/* Since: 0.4.2 */
+	AS_STORE_WATCH_FLAG_REMOVED			= 2,	/* Since: 0.4.2 */
+	/*< private >*/
+	AS_STORE_WATCH_FLAG_LAST
+} AsStoreWatchFlags;
+
 /**
  * AsStoreError:
  * @AS_STORE_ERROR_FAILED:			Generic failure
@@ -130,7 +146,6 @@ gboolean	 as_store_from_file		(AsStore	*store,
 						 GError		**error);
 gboolean	 as_store_from_xml		(AsStore	*store,
 						 const gchar	*data,
-						 gssize		 data_len,
 						 const gchar	*icon_root,
 						 GError		**error);
 gboolean	 as_store_load			(AsStore	*store,
@@ -148,8 +163,15 @@ GPtrArray	*as_store_get_apps_by_metadata	(AsStore	*store,
 						 const gchar	*value);
 AsApp		*as_store_get_app_by_id		(AsStore	*store,
 						 const gchar	*id);
+AsApp		*as_store_get_app_by_id_with_fallbacks (AsStore	*store,
+						 const gchar	*id);
 AsApp		*as_store_get_app_by_pkgname	(AsStore	*store,
 						 const gchar	*pkgname);
+AsApp		*as_store_get_app_by_pkgnames	(AsStore	*store,
+						 gchar		**pkgnames);
+AsApp		*as_store_get_app_by_provide	(AsStore	*store,
+						 AsProvideKind	 kind,
+						 const gchar	*value);
 void		 as_store_add_app		(AsStore	*store,
 						 AsApp		*app);
 void		 as_store_remove_app		(AsStore	*store,
@@ -181,6 +203,9 @@ void		 as_store_set_api_version	(AsStore	*store,
 AsStoreAddFlags	 as_store_get_add_flags		(AsStore	*store);
 void		 as_store_set_add_flags		(AsStore	*store,
 						 AsStoreAddFlags add_flags);
+AsStoreWatchFlags as_store_get_watch_flags	(AsStore	*store);
+void		 as_store_set_watch_flags	(AsStore	*store,
+						 AsStoreWatchFlags watch_flags);
 GPtrArray	*as_store_validate		(AsStore	*store,
 						 AsAppValidateFlags flags,
 						 GError		**error);
