@@ -34,7 +34,6 @@
 
 #include <fnmatch.h>
 #include <string.h>
-#include <libsoup/soup.h>
 #include <archive_entry.h>
 #include <archive.h>
 #include <stdlib.h>
@@ -64,25 +63,6 @@ as_utils_error_quark (void)
 	return quark;
 }
 
-/**
- * as_strndup:
- * @text: the text to copy.
- * @text_len: the length of @text, or -1 if @text is NULL terminated.
- *
- * Copies a string, with an optional length argument.
- *
- * Returns: (transfer full): a newly allocated %NULL terminated string
- *
- * Since: 0.1.0
- **/
-gchar *
-as_strndup (const gchar *text, gssize text_len)
-{
-	if (text_len < 0)
-		return g_strdup (text);
-	return g_strndup (text, text_len);
-}
-
 /**
  * as_markup_strsplit_words:
  * @text: the text to split.
@@ -197,7 +177,6 @@ as_markup_render_li (GString *str, AsMarkupConvertFormat format, const gchar *da
 /**
  * as_markup_convert:
  * @markup: the text to copy.
- * @markup_len: the length of @markup, or -1 if @markup is NULL terminated.
  * @format: the #AsMarkupConvertFormat, e.g. %AS_MARKUP_CONVERT_FORMAT_MARKDOWN
  * @error: A #GError or %NULL
  *
@@ -208,7 +187,7 @@ as_markup_render_li (GString *str, AsMarkupConvertFormat format, const gchar *da
  * Since: 0.3.5
  **/
 gchar *
-as_markup_convert (const gchar *markup, gssize markup_len,
+as_markup_convert (const gchar *markup,
 		   AsMarkupConvertFormat format, GError **error)
 {
 	GNode *tmp;
@@ -219,19 +198,16 @@ as_markup_convert (const gchar *markup, gssize markup_len,
 	_cleanup_string_free_ GString *str = NULL;
 
 	/* is this actually markup */
-	if (g_strstr_len (markup, markup_len, "<") == NULL)
-		return as_strndup (markup, markup_len);
+	if (g_strstr_len (markup, -1, "<") == NULL)
+		return g_strdup (markup);
 
 	/* load */
-	root = as_node_from_xml (markup,
-				 markup_len,
-				 AS_NODE_FROM_XML_FLAG_NONE,
-				 error);
+	root = as_node_from_xml (markup, AS_NODE_FROM_XML_FLAG_NONE, error);
 	if (root == NULL)
 		return NULL;
 
 	/* format */
-	str = g_string_sized_new (markup_len);
+	str = g_string_new ("");
 	for (tmp = root->children; tmp != NULL; tmp = tmp->next) {
 
 		tag = as_node_get_name (tmp);
@@ -275,7 +251,6 @@ as_markup_convert (const gchar *markup, gssize markup_len,
 /**
  * as_markup_convert_simple:
  * @markup: the text to copy.
- * @markup_len: the length of @markup, or -1 if @markup is NULL terminated.
  * @error: A #GError or %NULL
  *
  * Converts an XML description into a printable form.
@@ -285,11 +260,9 @@ as_markup_convert (const gchar *markup, gssize markup_len,
  * Since: 0.1.0
  **/
 gchar *
-as_markup_convert_simple (const gchar *markup,
-			  gssize markup_len,
-			  GError **error)
+as_markup_convert_simple (const gchar *markup, GError **error)
 {
-	return as_markup_convert (markup, markup_len,
+	return as_markup_convert (markup,
 				  AS_MARKUP_CONVERT_FORMAT_SIMPLE,
 				  error);
 }
@@ -675,75 +648,6 @@ as_utils_is_spdx_license (const gchar *license)
 	return TRUE;
 }
 
-/**
- * as_utils_check_url_exists:
- * @url: the URL to check.
- * @timeout: the timeout in seconds.
- * @error: A #GError or %NULL
- *
- * Checks to see if a URL is reachable.
- *
- * Returns: %TRUE if the URL was reachable and pointed to a non-zero-length file.
- *
- * Since: 0.1.5
- **/
-gboolean
-as_utils_check_url_exists (const gchar *url, guint timeout, GError **error)
-{
-	_cleanup_object_unref_ SoupMessage *msg = NULL;
-	_cleanup_object_unref_ SoupSession *session = NULL;
-	_cleanup_uri_unref_ SoupURI *base_uri = NULL;
-
-	/* GET file */
-	base_uri = soup_uri_new (url);
-	if (base_uri == NULL) {
-		g_set_error_literal (error,
-				     AS_NODE_ERROR,
-				     AS_NODE_ERROR_FAILED,
-				     "URL not valid");
-		return FALSE;
-	}
-	msg = soup_message_new_from_uri (SOUP_METHOD_GET, base_uri);
-	if (msg == NULL) {
-		g_set_error_literal (error,
-				     AS_NODE_ERROR,
-				     AS_NODE_ERROR_FAILED,
-				     "Failed to setup message");
-		return FALSE;
-	}
-	session = soup_session_sync_new_with_options (SOUP_SESSION_USER_AGENT,
-						      "libappstream-glib",
-						      SOUP_SESSION_TIMEOUT,
-						      timeout,
-						      NULL);
-	if (session == NULL) {
-		g_set_error_literal (error,
-				     AS_NODE_ERROR,
-				     AS_NODE_ERROR_FAILED,
-				     "Failed to set up networking");
-		return FALSE;
-	}
-
-	/* send sync */
-	if (soup_session_send_message (session, msg) != SOUP_STATUS_OK) {
-		g_set_error_literal (error,
-				     AS_NODE_ERROR,
-				     AS_NODE_ERROR_FAILED,
-				     msg->reason_phrase);
-		return FALSE;
-	}
-
-	/* check if it's a zero sized file */
-	if (msg->response_body->length == 0) {
-		g_set_error (error,
-			     AS_NODE_ERROR,
-			     AS_NODE_ERROR_FAILED,
-			     "Returned a zero length file");
-		return FALSE;
-	}
-	return TRUE;
-}
-
 /**
  * as_pixbuf_blur_private:
  **/
@@ -1072,7 +976,7 @@ as_utils_find_icon_filename_full (const gchar *destdir,
 					       pixmap_dirs[i],
 					       search,
 					       supported_ext[j]);
-			if (g_file_test (tmp, G_FILE_TEST_EXISTS))
+			if (g_file_test (tmp, G_FILE_TEST_IS_REGULAR))
 				return g_strdup (tmp);
 		}
 	}
@@ -1107,77 +1011,6 @@ as_utils_find_icon_filename (const gchar *destdir,
 						 error);
 }
 
-/**
- * as_utils_get_string_overlap_prefix:
- */
-static gchar *
-as_utils_get_string_overlap_prefix (const gchar *s1, const gchar *s2)
-{
-	guint i;
-	for (i = 0; s1[i] != '\0' && s2[i] != '\0'; i++) {
-		if (s1[i] != s2[i])
-			break;
-	}
-	if (i == 0)
-		return NULL;
-	if (s1[i - 1] == '-' || s1[i - 1] == '.')
-		i--;
-	return g_strndup (s1, i);
-}
-
-/**
- * as_utils_get_string_overlap_suffix:
- */
-static gchar *
-as_utils_get_string_overlap_suffix (const gchar *s1, const gchar *s2)
-{
-	guint i;
-	guint len1 = strlen (s1);
-	guint len2 = strlen (s2);
-	for (i = 0; i <= len1 && i <= len2; i++) {
-		if (s1[len1 - i] != s2[len2 - i])
-			break;
-	}
-	if (i <= 1)
-		return NULL;
-	return g_strdup (&s1[len1 - i + 1]);
-}
-
-/**
- * as_utils_get_string_overlap:
- * @s1: A string.
- * @s2: Another string
- *
- * Return a prefix and sufffix that is common to both strings.
- *
- * Returns: (transfer full): a newly allocated %NULL terminated string, or %NULL
- *
- * Since: 0.3.1
- */
-gchar *
-as_utils_get_string_overlap (const gchar *s1, const gchar *s2)
-{
-	_cleanup_free_ gchar *prefix = NULL;
-	_cleanup_free_ gchar *suffix = NULL;
-
-	g_return_val_if_fail (s1 != NULL, NULL);
-	g_return_val_if_fail (s2 != NULL, NULL);
-
-	/* same? */
-	if (g_strcmp0 (s1, s2) == 0)
-		return g_strdup (s1);
-
-	prefix = as_utils_get_string_overlap_prefix (s1, s2);
-	suffix = as_utils_get_string_overlap_suffix (s1, s2);
-	if (prefix == NULL && suffix == NULL)
-		return NULL;
-	if (prefix != NULL && suffix == NULL)
-		return g_strdup (prefix);
-	if (prefix == NULL && suffix != NULL)
-		return g_strdup (suffix);
-	return g_strdup_printf ("%s%s", prefix, suffix);
-}
-
 /**
  * as_utils_location_get_prefix:
  **/
@@ -1588,3 +1421,97 @@ as_utils_vercmp (const gchar *version_a, const gchar *version_b)
 	/* we really shouldn't get here */
 	return 0;
 }
+
+/**
+ * as_ptr_array_find_string:
+ * @array: gchar* array
+ * @value: string to find
+ *
+ * Finds a string in a pointer array.
+ *
+ * Returns: the const string, or %NULL if not found
+ **/
+const gchar *
+as_ptr_array_find_string (GPtrArray *array, const gchar *value)
+{
+	const gchar *tmp;
+	guint i;
+	for (i = 0; i < array->len; i++) {
+		tmp = g_ptr_array_index (array, i);
+		if (g_strcmp0 (tmp, value) == 0)
+			return tmp;
+	}
+	return NULL;
+}
+
+/**
+ * as_utils_guid_is_xdigit:
+ **/
+static gboolean
+as_utils_guid_is_xdigit (const gchar *str)
+{
+	guint i;
+	for (i = 0; str[i] != '\0'; i++) {
+		if (!g_ascii_isxdigit (str[i]))
+			return FALSE;
+	}
+	return TRUE;
+}
+
+/**
+ * as_utils_guid_is_valid:
+ * @guid: string to check
+ *
+ * Checks the source string is a valid string GUID descriptor.
+ *
+ * Returns: %TRUE if @guid was a valid GUID, %FALSE otherwise
+ *
+ * Since: 0.5.0
+ **/
+gboolean
+as_utils_guid_is_valid (const gchar *guid)
+{
+	_cleanup_strv_free_ gchar **split = NULL;
+	if (guid == NULL)
+		return FALSE;
+	split = g_strsplit (guid, "-", -1);
+	if (g_strv_length (split) != 5)
+		return FALSE;
+	if (strlen (split[0]) != 8 || !as_utils_guid_is_xdigit (split[0]))
+		return FALSE;
+	if (strlen (split[1]) != 4 || !as_utils_guid_is_xdigit (split[1]))
+		return FALSE;
+	if (strlen (split[2]) != 4 || !as_utils_guid_is_xdigit (split[2]))
+		return FALSE;
+	if (strlen (split[3]) != 4 || !as_utils_guid_is_xdigit (split[3]))
+		return FALSE;
+	if (strlen (split[4]) != 12 || !as_utils_guid_is_xdigit (split[4]))
+		return FALSE;
+	return TRUE;
+}
+
+/**
+ * as_utils_guid_from_string:
+ * @str: A source string to use as a key
+ *
+ * Returns a GUID for a given string. This uses SHA1 and some string
+ * modification so even small differences in the @str will produce radically
+ * different GUID return values.
+ *
+ * Returns: A new GUID, or %NULL if the string was invalid
+ *
+ * Since: 0.5.0
+ **/
+gchar *
+as_utils_guid_from_string (const gchar *str)
+{
+	gchar *tmp;
+	tmp = g_compute_checksum_for_string (G_CHECKSUM_SHA1, str, -1);
+	tmp[8] = '-';
+	tmp[13] = '-';
+	tmp[18] = '-';
+	tmp[23] = '-';
+	tmp[36] = '\0';
+	g_assert (as_utils_guid_is_valid (tmp));
+	return tmp;
+}
